@@ -4,11 +4,11 @@
 #include <QtCore/QStringList>
 #include <QtCore/QDebug>
 #include <qmetaobject.h>
-#include <__package_shared.h>
 
 #include <qcolor.h>
 #include <QVariant>
 #include <qcolor.h>
+#include <qdatastream.h>
 #include <qstringlist.h>
 
 static const char * const qtscript_QColor_function_names[] = {
@@ -58,6 +58,7 @@ static const char * const qtscript_QColor_function_names[] = {
     , "magentaF"
     , "name"
     , "equals"
+    , "readFrom"
     , "red"
     , "redF"
     , "rgb"
@@ -89,6 +90,7 @@ static const char * const qtscript_QColor_function_names[] = {
     , "toRgb"
     , "value"
     , "valueF"
+    , "writeTo"
     , "yellow"
     , "yellowF"
     , "toString"
@@ -141,6 +143,7 @@ static const char * const qtscript_QColor_function_signatures[] = {
     , ""
     , ""
     , "QColor c"
+    , "QDataStream arg__1"
     , ""
     , ""
     , ""
@@ -172,6 +175,7 @@ static const char * const qtscript_QColor_function_signatures[] = {
     , ""
     , ""
     , ""
+    , "QDataStream arg__1"
     , ""
     , ""
 ""
@@ -224,6 +228,7 @@ static const int qtscript_QColor_function_lengths[] = {
     , 0
     , 0
     , 1
+    , 1
     , 0
     , 0
     , 0
@@ -255,6 +260,7 @@ static const int qtscript_QColor_function_lengths[] = {
     , 0
     , 0
     , 0
+    , 1
     , 0
     , 0
     , 0
@@ -275,6 +281,7 @@ Q_DECLARE_METATYPE(QColor*)
 Q_DECLARE_METATYPE(QColor::Spec)
 Q_DECLARE_METATYPE(int*)
 Q_DECLARE_METATYPE(qreal*)
+Q_DECLARE_METATYPE(QDataStream*)
 Q_DECLARE_METATYPE(Qt::GlobalColor)
 
 static QScriptValue qtscript_create_enum_class_helper(
@@ -378,7 +385,7 @@ static QScriptValue qtscript_QColor_prototype_call(QScriptContext *context, QScr
     if (context->callee().isFunction())
         _id = context->callee().data().toUInt32();
     else
-        _id = 0xBABE0000 + 65;
+        _id = 0xBABE0000 + 67;
 #endif
     Q_ASSERT((_id & 0xFFFF0000) == 0xBABE0000);
     _id &= 0x0000FFFF;
@@ -649,48 +656,56 @@ static QScriptValue qtscript_QColor_prototype_call(QScriptContext *context, QScr
     break;
 
     case 32:
+    if (context->argumentCount() == 1) {
+        QDataStream* _q_arg0 = qscriptvalue_cast<QDataStream*>(context->argument(0));
+        operator>>(*_q_arg0, *_q_self);
+        return context->engine()->undefinedValue();
+    }
+    break;
+
+    case 33:
     if (context->argumentCount() == 0) {
         int _q_result = _q_self->red();
         return QScriptValue(context->engine(), _q_result);
     }
     break;
 
-    case 33:
+    case 34:
     if (context->argumentCount() == 0) {
         qreal _q_result = _q_self->redF();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 34:
-    if (context->argumentCount() == 0) {
-        unsigned int _q_result = _q_self->rgb();
-        return QScriptValue(context->engine(), _q_result);
-    }
-    break;
-
     case 35:
     if (context->argumentCount() == 0) {
-        unsigned int _q_result = _q_self->rgba();
+        uint _q_result = _q_self->rgb();
         return QScriptValue(context->engine(), _q_result);
     }
     break;
 
     case 36:
     if (context->argumentCount() == 0) {
-        int _q_result = _q_self->saturation();
+        uint _q_result = _q_self->rgba();
         return QScriptValue(context->engine(), _q_result);
     }
     break;
 
     case 37:
+    if (context->argumentCount() == 0) {
+        int _q_result = _q_self->saturation();
+        return QScriptValue(context->engine(), _q_result);
+    }
+    break;
+
+    case 38:
     if (context->argumentCount() == 0) {
         qreal _q_result = _q_self->saturationF();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 38:
+    case 39:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
         _q_self->setAlpha(_q_arg0);
@@ -698,7 +713,7 @@ static QScriptValue qtscript_QColor_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 39:
+    case 40:
     if (context->argumentCount() == 1) {
         qreal _q_arg0 = qscriptvalue_cast<qreal>(context->argument(0));
         _q_self->setAlphaF(_q_arg0);
@@ -706,7 +721,7 @@ static QScriptValue qtscript_QColor_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 40:
+    case 41:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
         _q_self->setBlue(_q_arg0);
@@ -714,7 +729,7 @@ static QScriptValue qtscript_QColor_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 41:
+    case 42:
     if (context->argumentCount() == 1) {
         qreal _q_arg0 = qscriptvalue_cast<qreal>(context->argument(0));
         _q_self->setBlueF(_q_arg0);
@@ -722,7 +737,7 @@ static QScriptValue qtscript_QColor_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 42:
+    case 43:
     if (context->argumentCount() == 4) {
         int _q_arg0 = context->argument(0).toInt32();
         int _q_arg1 = context->argument(1).toInt32();
@@ -742,7 +757,7 @@ static QScriptValue qtscript_QColor_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 43:
+    case 44:
     if (context->argumentCount() == 4) {
         qreal _q_arg0 = qscriptvalue_cast<qreal>(context->argument(0));
         qreal _q_arg1 = qscriptvalue_cast<qreal>(context->argument(1));
@@ -762,7 +777,7 @@ static QScriptValue qtscript_QColor_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 44:
+    case 45:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
         _q_self->setGreen(_q_arg0);
@@ -770,7 +785,7 @@ static QScriptValue qtscript_QColor_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 45:
+    case 46:
     if (context->argumentCount() == 1) {
         qreal _q_arg0 = qscriptvalue_cast<qreal>(context->argument(0));
         _q_self->setGreenF(_q_arg0);
@@ -778,7 +793,7 @@ static QScriptValue qtscript_QColor_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 46:
+    case 47:
     if (context->argumentCount() == 3) {
         int _q_arg0 = context->argument(0).toInt32();
         int _q_arg1 = context->argument(1).toInt32();
@@ -796,7 +811,7 @@ static QScriptValue qtscript_QColor_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 47:
+    case 48:
     if (context->argumentCount() == 3) {
         qreal _q_arg0 = qscriptvalue_cast<qreal>(context->argument(0));
         qreal _q_arg1 = qscriptvalue_cast<qreal>(context->argument(1));
@@ -814,7 +829,7 @@ static QScriptValue qtscript_QColor_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 48:
+    case 49:
     if (context->argumentCount() == 3) {
         int _q_arg0 = context->argument(0).toInt32();
         int _q_arg1 = context->argument(1).toInt32();
@@ -832,7 +847,7 @@ static QScriptValue qtscript_QColor_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 49:
+    case 50:
     if (context->argumentCount() == 3) {
         qreal _q_arg0 = qscriptvalue_cast<qreal>(context->argument(0));
         qreal _q_arg1 = qscriptvalue_cast<qreal>(context->argument(1));
@@ -850,7 +865,7 @@ static QScriptValue qtscript_QColor_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 50:
+    case 51:
     if (context->argumentCount() == 1) {
         QString _q_arg0 = context->argument(0).toString();
         _q_self->setNamedColor(_q_arg0);
@@ -858,7 +873,7 @@ static QScriptValue qtscript_QColor_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 51:
+    case 52:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
         _q_self->setRed(_q_arg0);
@@ -866,7 +881,7 @@ static QScriptValue qtscript_QColor_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 52:
+    case 53:
     if (context->argumentCount() == 1) {
         qreal _q_arg0 = qscriptvalue_cast<qreal>(context->argument(0));
         _q_self->setRedF(_q_arg0);
@@ -874,7 +889,7 @@ static QScriptValue qtscript_QColor_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 53:
+    case 54:
     if (context->argumentCount() == 1) {
         uint _q_arg0 = context->argument(0).toUInt32();
         _q_self->setRgb(_q_arg0);
@@ -897,7 +912,7 @@ static QScriptValue qtscript_QColor_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 54:
+    case 55:
     if (context->argumentCount() == 3) {
         qreal _q_arg0 = qscriptvalue_cast<qreal>(context->argument(0));
         qreal _q_arg1 = qscriptvalue_cast<qreal>(context->argument(1));
@@ -915,7 +930,7 @@ static QScriptValue qtscript_QColor_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 55:
+    case 56:
     if (context->argumentCount() == 1) {
         uint _q_arg0 = context->argument(0).toUInt32();
         _q_self->setRgba(_q_arg0);
@@ -923,70 +938,78 @@ static QScriptValue qtscript_QColor_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 56:
+    case 57:
     if (context->argumentCount() == 0) {
         QColor::Spec _q_result = _q_self->spec();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 57:
+    case 58:
     if (context->argumentCount() == 0) {
         QColor _q_result = _q_self->toCmyk();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 58:
+    case 59:
     if (context->argumentCount() == 0) {
         QColor _q_result = _q_self->toHsl();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 59:
+    case 60:
     if (context->argumentCount() == 0) {
         QColor _q_result = _q_self->toHsv();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 60:
+    case 61:
     if (context->argumentCount() == 0) {
         QColor _q_result = _q_self->toRgb();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 61:
+    case 62:
     if (context->argumentCount() == 0) {
         int _q_result = _q_self->value();
         return QScriptValue(context->engine(), _q_result);
     }
     break;
 
-    case 62:
+    case 63:
     if (context->argumentCount() == 0) {
         qreal _q_result = _q_self->valueF();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 63:
+    case 64:
+    if (context->argumentCount() == 1) {
+        QDataStream* _q_arg0 = qscriptvalue_cast<QDataStream*>(context->argument(0));
+        operator<<(*_q_arg0, *_q_self);
+        return context->engine()->undefinedValue();
+    }
+    break;
+
+    case 65:
     if (context->argumentCount() == 0) {
         int _q_result = _q_self->yellow();
         return QScriptValue(context->engine(), _q_result);
     }
     break;
 
-    case 64:
+    case 66:
     if (context->argumentCount() == 0) {
         qreal _q_result = _q_self->yellowF();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 65: {
+    case 67: {
     QString result;
     QDebug d(&result);
     d << *_q_self;
@@ -1243,7 +1266,7 @@ QScriptValue qtscript_create_QColor_class(QScriptEngine *engine)
 {
     engine->setDefaultPrototype(qMetaTypeId<QColor*>(), QScriptValue());
     QScriptValue proto = engine->newVariant(qVariantFromValue((QColor*)0));
-    for (int i = 0; i < 66; ++i) {
+    for (int i = 0; i < 68; ++i) {
         QScriptValue fun = engine->newFunction(qtscript_QColor_prototype_call, qtscript_QColor_function_lengths[i+12]);
         fun.setData(QScriptValue(engine, uint(0xBABE0000 + i)));
         proto.setProperty(QString::fromLatin1(qtscript_QColor_function_names[i+12]),
