@@ -37,7 +37,6 @@ static const char * const qtscript_QIcon_function_names[] = {
     , "paint"
     , "pixmap"
     , "readFrom"
-    , "swap"
     , "writeTo"
     , "toString"
 };
@@ -62,7 +61,6 @@ static const char * const qtscript_QIcon_function_signatures[] = {
     , "QPainter painter, QRect rect, Alignment alignment, Mode mode, State state\nQPainter painter, int x, int y, int w, int h, Alignment alignment, Mode mode, State state"
     , "QSize size, Mode mode, State state\nint extent, Mode mode, State state\nint w, int h, Mode mode, State state"
     , "QDataStream arg__1"
-    , "QIcon other"
     , "QDataStream arg__1"
 ""
 };
@@ -88,7 +86,6 @@ static const int qtscript_QIcon_function_lengths[] = {
     , 4
     , 1
     , 1
-    , 1
     , 0
 };
 
@@ -279,7 +276,7 @@ static QScriptValue qtscript_QIcon_prototype_call(QScriptContext *context, QScri
     if (context->callee().isFunction())
         _id = context->callee().data().toUInt32();
     else
-        _id = 0xBABE0000 + 12;
+        _id = 0xBABE0000 + 11;
 #endif
     Q_ASSERT((_id & 0xFFFF0000) == 0xBABE0000);
     _id &= 0x0000FFFF;
@@ -564,14 +561,6 @@ static QScriptValue qtscript_QIcon_prototype_call(QScriptContext *context, QScri
     break;
 
     case 10:
-    if (context->argumentCount() == 1) {
-        QIcon _q_arg0 = qscriptvalue_cast<QIcon>(context->argument(0));
-        _q_self->swap(_q_arg0);
-        return context->engine()->undefinedValue();
-    }
-    break;
-
-    case 11:
     if (context->argumentCount() == 1) {
         QDataStream* _q_arg0 = qscriptvalue_cast<QDataStream*>(context->argument(0));
         operator<<(*_q_arg0, *_q_self);
@@ -579,7 +568,7 @@ static QScriptValue qtscript_QIcon_prototype_call(QScriptContext *context, QScri
     }
     break;
 
-    case 12: {
+    case 11: {
     QString result = QString::fromLatin1("QIcon");
     return QScriptValue(context->engine(), result);
     }
@@ -701,7 +690,7 @@ QScriptValue qtscript_create_QIcon_class(QScriptEngine *engine)
 {
     engine->setDefaultPrototype(qMetaTypeId<QIcon*>(), QScriptValue());
     QScriptValue proto = engine->newVariant(qVariantFromValue((QIcon*)0));
-    for (int i = 0; i < 13; ++i) {
+    for (int i = 0; i < 12; ++i) {
         QScriptValue fun = engine->newFunction(qtscript_QIcon_prototype_call, qtscript_QIcon_function_lengths[i+7]);
         fun.setData(QScriptValue(engine, uint(0xBABE0000 + i)));
         proto.setProperty(QString::fromLatin1(qtscript_QIcon_function_names[i+7]),
