@@ -453,6 +453,17 @@ int  QtScriptShell_QCheckBox::metric(QPaintDevice::PaintDeviceMetric  arg__1) co
     }
 }
 
+QSize  QtScriptShell_QCheckBox::minimumSizeHint() const
+{
+    QScriptValue _q_function = __qtscript_self.property("getMinimumSizeHint");
+    if (!_q_function.isFunction() || QTSCRIPT_IS_GENERATED_FUNCTION(_q_function)
+        || (__qtscript_self.propertyFlags("getMinimumSizeHint") & QScriptValue::QObjectMember)) {
+        return QCheckBox::minimumSizeHint();
+    } else {
+        return qscriptvalue_cast<QSize >(_q_function.call(__qtscript_self));
+    }
+}
+
 void QtScriptShell_QCheckBox::mouseDoubleClickEvent(QMouseEvent*  arg__1)
 {
     QScriptValue _q_function = __qtscript_self.property("mouseDoubleClickEvent");
