@@ -4,13 +4,12 @@
 #include <qvalidator.h>
 
 #include <QtScript/qscriptvalue.h>
-#include <__package_shared.h>
 
 class QtScriptShell_QDoubleValidator : public QDoubleValidator
 {
 public:
     QtScriptShell_QDoubleValidator(QObject*  parent = 0);
-    QtScriptShell_QDoubleValidator(double  bottom, double  top, int  decimals, QObject*  parent = 0);
+    QtScriptShell_QDoubleValidator(double  bottom, double  top, int  decimals, QObject*  parent);
     ~QtScriptShell_QDoubleValidator();
 
     void childEvent(QChildEvent*  arg__1);
