@@ -4,12 +4,9 @@
 #include <QtCore/QStringList>
 #include <QtCore/QDebug>
 #include <qmetaobject.h>
-#include <__package_shared.h>
 
 #include <qnetworkproxy.h>
 #include <QVariant>
-#include <qbytearray.h>
-#include <qlist.h>
 #include <qnetworkproxy.h>
 
 static const char * const qtscript_QNetworkProxy_function_names[] = {
@@ -19,25 +16,18 @@ static const char * const qtscript_QNetworkProxy_function_names[] = {
     , "setApplicationProxy"
     // prototype
     , "capabilities"
-    , "hasRawHeader"
-    , "header"
     , "hostName"
     , "isCachingProxy"
     , "isTransparentProxy"
     , "equals"
     , "password"
     , "port"
-    , "rawHeader"
-    , "rawHeaderList"
     , "setCapabilities"
-    , "setHeader"
     , "setHostName"
     , "setPassword"
     , "setPort"
-    , "setRawHeader"
     , "setType"
     , "setUser"
-    , "swap"
     , "type"
     , "user"
     , "toString"
@@ -50,25 +40,18 @@ static const char * const qtscript_QNetworkProxy_function_signatures[] = {
     , "QNetworkProxy proxy"
     // prototype
     , ""
-    , "QByteArray headerName"
-    , "KnownHeaders header"
     , ""
     , ""
     , ""
     , "QNetworkProxy other"
     , ""
     , ""
-    , "QByteArray headerName"
-    , ""
     , "Capabilities capab"
-    , "KnownHeaders header, Object value"
     , "String hostName"
     , "String password"
     , "unsigned short port"
-    , "QByteArray headerName, QByteArray value"
     , "ProxyType type"
     , "String userName"
-    , "QNetworkProxy other"
     , ""
     , ""
 ""
@@ -81,8 +64,6 @@ static const int qtscript_QNetworkProxy_function_lengths[] = {
     , 1
     // prototype
     , 0
-    , 1
-    , 1
     , 0
     , 0
     , 0
@@ -90,14 +71,9 @@ static const int qtscript_QNetworkProxy_function_lengths[] = {
     , 0
     , 0
     , 1
-    , 0
-    , 1
-    , 2
     , 1
     , 1
     , 1
-    , 2
-    , 1
     , 1
     , 1
     , 0
@@ -116,12 +92,11 @@ static QScriptValue qtscript_QNetworkProxy_throw_ambiguity_error_helper(
         .arg(functionName).arg(fullSignatures.join(QLatin1String("\n"))));
 }
 
+Q_DECLARE_METATYPE(QNetworkProxy)
 Q_DECLARE_METATYPE(QNetworkProxy*)
+Q_DECLARE_METATYPE(QNetworkProxy::ProxyType)
 Q_DECLARE_METATYPE(QNetworkProxy::Capability)
 Q_DECLARE_METATYPE(QFlags<QNetworkProxy::Capability>)
-Q_DECLARE_METATYPE(QNetworkProxy::ProxyType)
-Q_DECLARE_METATYPE(QNetworkRequest::KnownHeaders)
-Q_DECLARE_METATYPE(QList<QByteArray >)
 
 static QScriptValue qtscript_create_enum_class_helper(
     QScriptEngine *engine,
@@ -154,6 +129,81 @@ static QScriptValue qtscript_create_flags_class_helper(
     return engine->newFunction(construct, proto);
 }
 
+//
+// QNetworkProxy::ProxyType
+//
+
+static const QNetworkProxy::ProxyType qtscript_QNetworkProxy_ProxyType_values[] = {
+    QNetworkProxy::DefaultProxy
+    , QNetworkProxy::Socks5Proxy
+    , QNetworkProxy::NoProxy
+    , QNetworkProxy::HttpProxy
+    , QNetworkProxy::HttpCachingProxy
+    , QNetworkProxy::FtpCachingProxy
+};
+
+static const char * const qtscript_QNetworkProxy_ProxyType_keys[] = {
+    "DefaultProxy"
+    , "Socks5Proxy"
+    , "NoProxy"
+    , "HttpProxy"
+    , "HttpCachingProxy"
+    , "FtpCachingProxy"
+};
+
+static QString qtscript_QNetworkProxy_ProxyType_toStringHelper(QNetworkProxy::ProxyType value)
+{
+    if ((value >= QNetworkProxy::DefaultProxy) && (value <= QNetworkProxy::FtpCachingProxy))
+        return qtscript_QNetworkProxy_ProxyType_keys[static_cast<int>(value)-static_cast<int>(QNetworkProxy::DefaultProxy)];
+    return QString();
+}
+
+static QScriptValue qtscript_QNetworkProxy_ProxyType_toScriptValue(QScriptEngine *engine, const QNetworkProxy::ProxyType &value)
+{
+    QScriptValue clazz = engine->globalObject().property(QString::fromLatin1("QNetworkProxy"));
+    return clazz.property(qtscript_QNetworkProxy_ProxyType_toStringHelper(value));
+}
+
+static void qtscript_QNetworkProxy_ProxyType_fromScriptValue(const QScriptValue &value, QNetworkProxy::ProxyType &out)
+{
+    out = qvariant_cast<QNetworkProxy::ProxyType>(value.toVariant());
+}
+
+static QScriptValue qtscript_construct_QNetworkProxy_ProxyType(QScriptContext *context, QScriptEngine *engine)
+{
+    int arg = context->argument(0).toInt32();
+    if ((arg >= QNetworkProxy::DefaultProxy) && (arg <= QNetworkProxy::FtpCachingProxy))
+        return qScriptValueFromValue(engine,  static_cast<QNetworkProxy::ProxyType>(arg));
+    return context->throwError(QString::fromLatin1("ProxyType(): invalid enum value (%0)").arg(arg));
+}
+
+static QScriptValue qtscript_QNetworkProxy_ProxyType_valueOf(QScriptContext *context, QScriptEngine *engine)
+{
+    QNetworkProxy::ProxyType value = qscriptvalue_cast<QNetworkProxy::ProxyType>(context->thisObject());
+    return QScriptValue(engine, static_cast<int>(value));
+}
+
+static QScriptValue qtscript_QNetworkProxy_ProxyType_toString(QScriptContext *context, QScriptEngine *engine)
+{
+    QNetworkProxy::ProxyType value = qscriptvalue_cast<QNetworkProxy::ProxyType>(context->thisObject());
+    return QScriptValue(engine, qtscript_QNetworkProxy_ProxyType_toStringHelper(value));
+}
+
+static QScriptValue qtscript_create_QNetworkProxy_ProxyType_class(QScriptEngine *engine, QScriptValue &clazz)
+{
+    QScriptValue ctor = qtscript_create_enum_class_helper(
+        engine, qtscript_construct_QNetworkProxy_ProxyType,
+        qtscript_QNetworkProxy_ProxyType_valueOf, qtscript_QNetworkProxy_ProxyType_toString);
+    qScriptRegisterMetaType<QNetworkProxy::ProxyType>(engine, qtscript_QNetworkProxy_ProxyType_toScriptValue,
+        qtscript_QNetworkProxy_ProxyType_fromScriptValue, ctor.property(QString::fromLatin1("prototype")));
+    for (int i = 0; i < 6; ++i) {
+        clazz.setProperty(QString::fromLatin1(qtscript_QNetworkProxy_ProxyType_keys[i]),
+            engine->newVariant(qVariantFromValue(qtscript_QNetworkProxy_ProxyType_values[i])),
+            QScriptValue::ReadOnly | QScriptValue::Undeletable);
+    }
+    return ctor;
+}
+
 //
 // QNetworkProxy::Capability
 //
@@ -307,81 +357,6 @@ static QScriptValue qtscript_create_QNetworkProxy_Capabilities_class(QScriptEngi
     return ctor;
 }
 
-//
-// QNetworkProxy::ProxyType
-//
-
-static const QNetworkProxy::ProxyType qtscript_QNetworkProxy_ProxyType_values[] = {
-    QNetworkProxy::DefaultProxy
-    , QNetworkProxy::Socks5Proxy
-    , QNetworkProxy::NoProxy
-    , QNetworkProxy::HttpProxy
-    , QNetworkProxy::HttpCachingProxy
-    , QNetworkProxy::FtpCachingProxy
-};
-
-static const char * const qtscript_QNetworkProxy_ProxyType_keys[] = {
-    "DefaultProxy"
-    , "Socks5Proxy"
-    , "NoProxy"
-    , "HttpProxy"
-    , "HttpCachingProxy"
-    , "FtpCachingProxy"
-};
-
-static QString qtscript_QNetworkProxy_ProxyType_toStringHelper(QNetworkProxy::ProxyType value)
-{
-    if ((value >= QNetworkProxy::DefaultProxy) && (value <= QNetworkProxy::FtpCachingProxy))
-        return qtscript_QNetworkProxy_ProxyType_keys[static_cast<int>(value)-static_cast<int>(QNetworkProxy::DefaultProxy)];
-    return QString();
-}
-
-static QScriptValue qtscript_QNetworkProxy_ProxyType_toScriptValue(QScriptEngine *engine, const QNetworkProxy::ProxyType &value)
-{
-    QScriptValue clazz = engine->globalObject().property(QString::fromLatin1("QNetworkProxy"));
-    return clazz.property(qtscript_QNetworkProxy_ProxyType_toStringHelper(value));
-}
-
-static void qtscript_QNetworkProxy_ProxyType_fromScriptValue(const QScriptValue &value, QNetworkProxy::ProxyType &out)
-{
-    out = qvariant_cast<QNetworkProxy::ProxyType>(value.toVariant());
-}
-
-static QScriptValue qtscript_construct_QNetworkProxy_ProxyType(QScriptContext *context, QScriptEngine *engine)
-{
-    int arg = context->argument(0).toInt32();
-    if ((arg >= QNetworkProxy::DefaultProxy) && (arg <= QNetworkProxy::FtpCachingProxy))
-        return qScriptValueFromValue(engine,  static_cast<QNetworkProxy::ProxyType>(arg));
-    return context->throwError(QString::fromLatin1("ProxyType(): invalid enum value (%0)").arg(arg));
-}
-
-static QScriptValue qtscript_QNetworkProxy_ProxyType_valueOf(QScriptContext *context, QScriptEngine *engine)
-{
-    QNetworkProxy::ProxyType value = qscriptvalue_cast<QNetworkProxy::ProxyType>(context->thisObject());
-    return QScriptValue(engine, static_cast<int>(value));
-}
-
-static QScriptValue qtscript_QNetworkProxy_ProxyType_toString(QScriptContext *context, QScriptEngine *engine)
-{
-    QNetworkProxy::ProxyType value = qscriptvalue_cast<QNetworkProxy::ProxyType>(context->thisObject());
-    return QScriptValue(engine, qtscript_QNetworkProxy_ProxyType_toStringHelper(value));
-}
-
-static QScriptValue qtscript_create_QNetworkProxy_ProxyType_class(QScriptEngine *engine, QScriptValue &clazz)
-{
-    QScriptValue ctor = qtscript_create_enum_class_helper(
-        engine, qtscript_construct_QNetworkProxy_ProxyType,
-        qtscript_QNetworkProxy_ProxyType_valueOf, qtscript_QNetworkProxy_ProxyType_toString);
-    qScriptRegisterMetaType<QNetworkProxy::ProxyType>(engine, qtscript_QNetworkProxy_ProxyType_toScriptValue,
-        qtscript_QNetworkProxy_ProxyType_fromScriptValue, ctor.property(QString::fromLatin1("prototype")));
-    for (int i = 0; i < 6; ++i) {
-        clazz.setProperty(QString::fromLatin1(qtscript_QNetworkProxy_ProxyType_keys[i]),
-            engine->newVariant(qVariantFromValue(qtscript_QNetworkProxy_ProxyType_values[i])),
-            QScriptValue::ReadOnly | QScriptValue::Undeletable);
-    }
-    return ctor;
-}
-
 //
 // QNetworkProxy
 //
@@ -396,7 +371,7 @@ static QScriptValue qtscript_QNetworkProxy_prototype_call(QScriptContext *contex
     if (context->callee().isFunction())
         _id = context->callee().data().toUInt32();
     else
-        _id = 0xBABE0000 + 22;
+        _id = 0xBABE0000 + 15;
 #endif
     Q_ASSERT((_id & 0xFFFF0000) == 0xBABE0000);
     _id &= 0x0000FFFF;
@@ -416,43 +391,27 @@ static QScriptValue qtscript_QNetworkProxy_prototype_call(QScriptContext *contex
     break;
 
     case 1:
-    if (context->argumentCount() == 1) {
-        QByteArray _q_arg0 = qscriptvalue_cast<QByteArray>(context->argument(0));
-        bool _q_result = _q_self->hasRawHeader(_q_arg0);
-        return QScriptValue(context->engine(), _q_result);
-    }
-    break;
-
-    case 2:
-    if (context->argumentCount() == 1) {
-        QNetworkRequest::KnownHeaders _q_arg0 = qscriptvalue_cast<QNetworkRequest::KnownHeaders>(context->argument(0));
-        QVariant _q_result = _q_self->header(_q_arg0);
-        return qScriptValueFromValue(context->engine(), _q_result);
-    }
-    break;
-
-    case 3:
     if (context->argumentCount() == 0) {
         QString _q_result = _q_self->hostName();
         return QScriptValue(context->engine(), _q_result);
     }
     break;
 
-    case 4:
+    case 2:
     if (context->argumentCount() == 0) {
         bool _q_result = _q_self->isCachingProxy();
         return QScriptValue(context->engine(), _q_result);
     }
     break;
 
-    case 5:
+    case 3:
     if (context->argumentCount() == 0) {
         bool _q_result = _q_self->isTransparentProxy();
         return QScriptValue(context->engine(), _q_result);
     }
     break;
 
-    case 6:
+    case 4:
     if (context->argumentCount() == 1) {
         QNetworkProxy _q_arg0 = qscriptvalue_cast<QNetworkProxy>(context->argument(0));
         bool _q_result = _q_self->operator==(_q_arg0);
@@ -460,36 +419,21 @@ static QScriptValue qtscript_QNetworkProxy_prototype_call(QScriptContext *contex
     }
     break;
 
-    case 7:
+    case 5:
     if (context->argumentCount() == 0) {
         QString _q_result = _q_self->password();
         return QScriptValue(context->engine(), _q_result);
     }
     break;
 
-    case 8:
+    case 6:
     if (context->argumentCount() == 0) {
         unsigned short _q_result = _q_self->port();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 9:
-    if (context->argumentCount() == 1) {
-        QByteArray _q_arg0 = qscriptvalue_cast<QByteArray>(context->argument(0));
-        QByteArray _q_result = _q_self->rawHeader(_q_arg0);
-        return qScriptValueFromValue(context->engine(), _q_result);
-    }
-    break;
-
-    case 10:
-    if (context->argumentCount() == 0) {
-        QList<QByteArray > _q_result = _q_self->rawHeaderList();
-        return qScriptValueFromSequence(context->engine(), _q_result);
-    }
-    break;
-
-    case 11:
+    case 7:
     if (context->argumentCount() == 1) {
         QFlags<QNetworkProxy::Capability> _q_arg0 = qscriptvalue_cast<QFlags<QNetworkProxy::Capability> >(context->argument(0));
         _q_self->setCapabilities(_q_arg0);
@@ -497,16 +441,7 @@ static QScriptValue qtscript_QNetworkProxy_prototype_call(QScriptContext *contex
     }
     break;
 
-    case 12:
-    if (context->argumentCount() == 2) {
-        QNetworkRequest::KnownHeaders _q_arg0 = qscriptvalue_cast<QNetworkRequest::KnownHeaders>(context->argument(0));
-        QVariant _q_arg1 = context->argument(1).toVariant();
-        _q_self->setHeader(_q_arg0, _q_arg1);
-        return context->engine()->undefinedValue();
-    }
-    break;
-
-    case 13:
+    case 8:
     if (context->argumentCount() == 1) {
         QString _q_arg0 = context->argument(0).toString();
         _q_self->setHostName(_q_arg0);
@@ -514,7 +449,7 @@ static QScriptValue qtscript_QNetworkProxy_prototype_call(QScriptContext *contex
     }
     break;
 
-    case 14:
+    case 9:
     if (context->argumentCount() == 1) {
         QString _q_arg0 = context->argument(0).toString();
         _q_self->setPassword(_q_arg0);
@@ -522,7 +457,7 @@ static QScriptValue qtscript_QNetworkProxy_prototype_call(QScriptContext *contex
     }
     break;
 
-    case 15:
+    case 10:
     if (context->argumentCount() == 1) {
         unsigned short _q_arg0 = qscriptvalue_cast<unsigned short>(context->argument(0));
         _q_self->setPort(_q_arg0);
@@ -530,16 +465,7 @@ static QScriptValue qtscript_QNetworkProxy_prototype_call(QScriptContext *contex
     }
     break;
 
-    case 16:
-    if (context->argumentCount() == 2) {
-        QByteArray _q_arg0 = qscriptvalue_cast<QByteArray>(context->argument(0));
-        QByteArray _q_arg1 = qscriptvalue_cast<QByteArray>(context->argument(1));
-        _q_self->setRawHeader(_q_arg0, _q_arg1);
-        return context->engine()->undefinedValue();
-    }
-    break;
-
-    case 17:
+    case 11:
     if (context->argumentCount() == 1) {
         QNetworkProxy::ProxyType _q_arg0 = qscriptvalue_cast<QNetworkProxy::ProxyType>(context->argument(0));
         _q_self->setType(_q_arg0);
@@ -547,7 +473,7 @@ static QScriptValue qtscript_QNetworkProxy_prototype_call(QScriptContext *contex
     }
     break;
 
-    case 18:
+    case 12:
     if (context->argumentCount() == 1) {
         QString _q_arg0 = context->argument(0).toString();
         _q_self->setUser(_q_arg0);
@@ -555,32 +481,22 @@ static QScriptValue qtscript_QNetworkProxy_prototype_call(QScriptContext *contex
     }
     break;
 
-    case 19:
-    if (context->argumentCount() == 1) {
-        QNetworkProxy _q_arg0 = qscriptvalue_cast<QNetworkProxy>(context->argument(0));
-        _q_self->swap(_q_arg0);
-        return context->engine()->undefinedValue();
-    }
-    break;
-
-    case 20:
+    case 13:
     if (context->argumentCount() == 0) {
         QNetworkProxy::ProxyType _q_result = _q_self->type();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 21:
+    case 14:
     if (context->argumentCount() == 0) {
         QString _q_result = _q_self->user();
         return QScriptValue(context->engine(), _q_result);
     }
     break;
 
-    case 22: {
-    QString result;
-    QDebug d(&result);
-    d << *_q_self;
+    case 15: {
+    QString result = QString::fromLatin1("QNetworkProxy");
     return QScriptValue(context->engine(), result);
     }
 
@@ -678,7 +594,7 @@ QScriptValue qtscript_create_QNetworkProxy_class(QScriptEngine *engine)
 {
     engine->setDefaultPrototype(qMetaTypeId<QNetworkProxy*>(), QScriptValue());
     QScriptValue proto = engine->newVariant(qVariantFromValue((QNetworkProxy*)0));
-    for (int i = 0; i < 23; ++i) {
+    for (int i = 0; i < 16; ++i) {
         QScriptValue fun = engine->newFunction(qtscript_QNetworkProxy_prototype_call, qtscript_QNetworkProxy_function_lengths[i+3]);
         fun.setData(QScriptValue(engine, uint(0xBABE0000 + i)));
         proto.setProperty(QString::fromLatin1(qtscript_QNetworkProxy_function_names[i+3]),
@@ -698,11 +614,11 @@ QScriptValue qtscript_create_QNetworkProxy_class(QScriptEngine *engine)
             fun, QScriptValue::SkipInEnumeration);
     }
 
+    ctor.setProperty(QString::fromLatin1("ProxyType"),
+        qtscript_create_QNetworkProxy_ProxyType_class(engine, ctor));
     ctor.setProperty(QString::fromLatin1("Capability"),
         qtscript_create_QNetworkProxy_Capability_class(engine, ctor));
     ctor.setProperty(QString::fromLatin1("Capabilities"),
         qtscript_create_QNetworkProxy_Capabilities_class(engine));
-    ctor.setProperty(QString::fromLatin1("ProxyType"),
-        qtscript_create_QNetworkProxy_ProxyType_class(engine, ctor));
     return ctor;
 }
