@@ -250,9 +250,6 @@ static const QWebSettings::WebGraphic qtscript_QWebSettings_WebGraphic_values[]
     , QWebSettings::DefaultFrameIconGraphic
     , QWebSettings::TextAreaSizeGripCornerGraphic
     , QWebSettings::DeleteButtonGraphic
-    , QWebSettings::InputSpeechButtonGraphic
-    , QWebSettings::SearchCancelButtonGraphic
-    , QWebSettings::SearchCancelButtonPressedGraphic
 };
 
 static const char * const qtscript_QWebSettings_WebGraphic_keys[] = {
@@ -261,14 +258,11 @@ static const char * const qtscript_QWebSettings_WebGraphic_keys[] = {
     , "DefaultFrameIconGraphic"
     , "TextAreaSizeGripCornerGraphic"
     , "DeleteButtonGraphic"
-    , "InputSpeechButtonGraphic"
-    , "SearchCancelButtonGraphic"
-    , "SearchCancelButtonPressedGraphic"
 };
 
 static QString qtscript_QWebSettings_WebGraphic_toStringHelper(QWebSettings::WebGraphic value)
 {
-    if ((value >= QWebSettings::MissingImageGraphic) && (value <= QWebSettings::SearchCancelButtonPressedGraphic))
+    if ((value >= QWebSettings::MissingImageGraphic) && (value <= QWebSettings::DeleteButtonGraphic))
         return qtscript_QWebSettings_WebGraphic_keys[static_cast<int>(value)-static_cast<int>(QWebSettings::MissingImageGraphic)];
     return QString();
 }
@@ -287,7 +281,7 @@ static void qtscript_QWebSettings_WebGraphic_fromScriptValue(const QScriptValue
 static QScriptValue qtscript_construct_QWebSettings_WebGraphic(QScriptContext *context, QScriptEngine *engine)
 {
     int arg = context->argument(0).toInt32();
-    if ((arg >= QWebSettings::MissingImageGraphic) && (arg <= QWebSettings::SearchCancelButtonPressedGraphic))
+    if ((arg >= QWebSettings::MissingImageGraphic) && (arg <= QWebSettings::DeleteButtonGraphic))
         return qScriptValueFromValue(engine,  static_cast<QWebSettings::WebGraphic>(arg));
     return context->throwError(QString::fromLatin1("WebGraphic(): invalid enum value (%0)").arg(arg));
 }
@@ -311,7 +305,7 @@ static QScriptValue qtscript_create_QWebSettings_WebGraphic_class(QScriptEngine
         qtscript_QWebSettings_WebGraphic_valueOf, qtscript_QWebSettings_WebGraphic_toString);
     qScriptRegisterMetaType<QWebSettings::WebGraphic>(engine, qtscript_QWebSettings_WebGraphic_toScriptValue,
         qtscript_QWebSettings_WebGraphic_fromScriptValue, ctor.property(QString::fromLatin1("prototype")));
-    for (int i = 0; i < 8; ++i) {
+    for (int i = 0; i < 5; ++i) {
         clazz.setProperty(QString::fromLatin1(qtscript_QWebSettings_WebGraphic_keys[i]),
             engine->newVariant(qVariantFromValue(qtscript_QWebSettings_WebGraphic_values[i])),
             QScriptValue::ReadOnly | QScriptValue::Undeletable);
@@ -422,9 +416,6 @@ static const QWebSettings::WebAttribute qtscript_QWebSettings_WebAttribute_value
     , QWebSettings::TiledBackingStoreEnabled
     , QWebSettings::FrameFlatteningEnabled
     , QWebSettings::SiteSpecificQuirksEnabled
-    , QWebSettings::JavascriptCanCloseWindows
-    , QWebSettings::WebGLEnabled
-    , QWebSettings::HyperlinkAuditingEnabled
 };
 
 static const char * const qtscript_QWebSettings_WebAttribute_keys[] = {
@@ -451,14 +442,11 @@ static const char * const qtscript_QWebSettings_WebAttribute_keys[] = {
     , "TiledBackingStoreEnabled"
     , "FrameFlatteningEnabled"
     , "SiteSpecificQuirksEnabled"
-    , "JavascriptCanCloseWindows"
-    , "WebGLEnabled"
-    , "HyperlinkAuditingEnabled"
 };
 
 static QString qtscript_QWebSettings_WebAttribute_toStringHelper(QWebSettings::WebAttribute value)
 {
-    if ((value >= QWebSettings::AutoLoadImages) && (value <= QWebSettings::HyperlinkAuditingEnabled))
+    if ((value >= QWebSettings::AutoLoadImages) && (value <= QWebSettings::SiteSpecificQuirksEnabled))
         return qtscript_QWebSettings_WebAttribute_keys[static_cast<int>(value)-static_cast<int>(QWebSettings::AutoLoadImages)];
     return QString();
 }
@@ -477,7 +465,7 @@ static void qtscript_QWebSettings_WebAttribute_fromScriptValue(const QScriptValu
 static QScriptValue qtscript_construct_QWebSettings_WebAttribute(QScriptContext *context, QScriptEngine *engine)
 {
     int arg = context->argument(0).toInt32();
-    if ((arg >= QWebSettings::AutoLoadImages) && (arg <= QWebSettings::HyperlinkAuditingEnabled))
+    if ((arg >= QWebSettings::AutoLoadImages) && (arg <= QWebSettings::SiteSpecificQuirksEnabled))
         return qScriptValueFromValue(engine,  static_cast<QWebSettings::WebAttribute>(arg));
     return context->throwError(QString::fromLatin1("WebAttribute(): invalid enum value (%0)").arg(arg));
 }
@@ -501,7 +489,7 @@ static QScriptValue qtscript_create_QWebSettings_WebAttribute_class(QScriptEngin
         qtscript_QWebSettings_WebAttribute_valueOf, qtscript_QWebSettings_WebAttribute_toString);
     qScriptRegisterMetaType<QWebSettings::WebAttribute>(engine, qtscript_QWebSettings_WebAttribute_toScriptValue,
         qtscript_QWebSettings_WebAttribute_fromScriptValue, ctor.property(QString::fromLatin1("prototype")));
-    for (int i = 0; i < 26; ++i) {
+    for (int i = 0; i < 23; ++i) {
         clazz.setProperty(QString::fromLatin1(qtscript_QWebSettings_WebAttribute_keys[i]),
             engine->newVariant(qVariantFromValue(qtscript_QWebSettings_WebAttribute_values[i])),
             QScriptValue::ReadOnly | QScriptValue::Undeletable);
