@@ -11,8 +11,6 @@
 #include <qvector.h>
 #include <qxmlstream.h>
 
-#include "qtscriptshell_QXmlStreamAttributes.h"
-
 static const char * const qtscript_QXmlStreamAttributes_function_names[] = {
     "QXmlStreamAttributes"
     // static
@@ -45,6 +43,7 @@ static const char * const qtscript_QXmlStreamAttributes_function_names[] = {
     , "size"
     , "squeeze"
     , "startsWith"
+    , "swap"
     , "toList"
     , "value"
     , "toString"
@@ -82,6 +81,7 @@ static const char * const qtscript_QXmlStreamAttributes_function_signatures[] =
     , ""
     , ""
     , "QXmlStreamAttribute t"
+    , "List other"
     , ""
     , "String namespaceUri, String name\nString qualifiedName"
 ""
@@ -119,6 +119,7 @@ static const int qtscript_QXmlStreamAttributes_function_lengths[] = {
     , 0
     , 0
     , 1
+    , 1
     , 0
     , 2
     , 0
@@ -137,8 +138,6 @@ static QScriptValue qtscript_QXmlStreamAttributes_throw_ambiguity_error_helper(
 
 Q_DECLARE_METATYPE(QXmlStreamAttributes)
 Q_DECLARE_METATYPE(QXmlStreamAttributes*)
-Q_DECLARE_METATYPE(QtScriptShell_QXmlStreamAttributes)
-Q_DECLARE_METATYPE(QtScriptShell_QXmlStreamAttributes*)
 Q_DECLARE_METATYPE(QXmlStreamAttribute)
 Q_DECLARE_METATYPE(QVector<QXmlStreamAttribute>)
 Q_DECLARE_METATYPE(QList<QXmlStreamAttribute>)
@@ -158,7 +157,7 @@ static QScriptValue qtscript_QXmlStreamAttributes_prototype_call(QScriptContext
     if (context->callee().isFunction())
         _id = context->callee().data().toUInt32();
     else
-        _id = 0xBABE0000 + 29;
+        _id = 0xBABE0000 + 30;
 #endif
     Q_ASSERT((_id & 0xFFFF0000) == 0xBABE0000);
     _id &= 0x0000FFFF;
@@ -435,13 +434,22 @@ static QScriptValue qtscript_QXmlStreamAttributes_prototype_call(QScriptContext
     break;
 
     case 27:
+    if (context->argumentCount() == 1) {
+        QVector<QXmlStreamAttribute> _q_arg0;
+        qScriptValueToSequence(context->argument(0), _q_arg0);
+        _q_self->swap(_q_arg0);
+        return context->engine()->undefinedValue();
+    }
+    break;
+
+    case 28:
     if (context->argumentCount() == 0) {
         QList<QXmlStreamAttribute> _q_result = _q_self->toList();
         return qScriptValueFromSequence(context->engine(), _q_result);
     }
     break;
 
-    case 28:
+    case 29:
     if (context->argumentCount() == 1) {
         QString _q_arg0 = context->argument(0).toString();
         QStringRef _q_result = _q_self->value(_q_arg0);
@@ -463,7 +471,7 @@ static QScriptValue qtscript_QXmlStreamAttributes_prototype_call(QScriptContext
     }
     break;
 
-    case 29: {
+    case 30: {
     QString result = QString::fromLatin1("QXmlStreamAttributes");
     return QScriptValue(context->engine(), result);
     }
@@ -487,9 +495,8 @@ static QScriptValue qtscript_QXmlStreamAttributes_static_call(QScriptContext *co
         return context->throwError(QString::fromLatin1("QXmlStreamAttributes(): Did you forget to construct with 'new'?"));
     }
     if (context->argumentCount() == 0) {
-        QtScriptShell_QXmlStreamAttributes _q_cpp_result;
-        QScriptValue _q_result = context->engine()->newVariant(context->thisObject(), qVariantFromValue((QXmlStreamAttributes)_q_cpp_result));
-        _q_cpp_result.__qtscript_self = _q_result;
+        QXmlStreamAttributes _q_cpp_result;
+        QScriptValue _q_result = context->engine()->newVariant(context->thisObject(), qVariantFromValue(_q_cpp_result));
         return _q_result;
     }
     break;
@@ -515,7 +522,7 @@ QScriptValue qtscript_create_QXmlStreamAttributes_class(QScriptEngine *engine)
 {
     engine->setDefaultPrototype(qMetaTypeId<QXmlStreamAttributes*>(), QScriptValue());
     QScriptValue proto = engine->newVariant(qVariantFromValue((QXmlStreamAttributes*)0));
-    for (int i = 0; i < 30; ++i) {
+    for (int i = 0; i < 31; ++i) {
         QScriptValue fun = engine->newFunction(qtscript_QXmlStreamAttributes_prototype_call, qtscript_QXmlStreamAttributes_function_lengths[i+2]);
         fun.setData(QScriptValue(engine, uint(0xBABE0000 + i)));
         proto.setProperty(QString::fromLatin1(qtscript_QXmlStreamAttributes_function_names[i+2]),
