@@ -4,7 +4,6 @@
 #include <QtCore/QStringList>
 #include <QtCore/QDebug>
 #include <qmetaobject.h>
-#include <__package_shared.h>
 
 #include <qimage.h>
 #include <QMatrix>
@@ -12,12 +11,12 @@
 #include <QVariant>
 #include <qbytearray.h>
 #include <qcolor.h>
+#include <qdatastream.h>
 #include <qimage.h>
 #include <qiodevice.h>
 #include <qmatrix.h>
 #include <qpaintdevice.h>
 #include <qpaintengine.h>
-#include <qpainter.h>
 #include <qpoint.h>
 #include <qrect.h>
 #include <qsize.h>
@@ -59,10 +58,12 @@ static const char * const qtscript_QImage_function_names[] = {
     , "load"
     , "loadFromData"
     , "mirrored"
+    , "numBytes"
     , "offset"
     , "equals"
     , "pixel"
     , "pixelIndex"
+    , "readFrom"
     , "rect"
     , "rgbSwapped"
     , "save"
@@ -72,9 +73,9 @@ static const char * const qtscript_QImage_function_names[] = {
     , "setAlphaChannel"
     , "setColor"
     , "setColorCount"
-    , "setDevicePixelRatio"
     , "setDotsPerMeterX"
     , "setDotsPerMeterY"
+    , "setNumColors"
     , "setOffset"
     , "setPixel"
     , "setText"
@@ -84,6 +85,7 @@ static const char * const qtscript_QImage_function_names[] = {
     , "textKeys"
     , "transformed"
     , "valid"
+    , "writeTo"
     , "toString"
 };
 
@@ -120,9 +122,11 @@ static const char * const qtscript_QImage_function_signatures[] = {
     , "QByteArray data, char aformat"
     , "bool horizontally, bool vertically"
     , ""
+    , ""
     , "QImage arg__1"
     , "QPoint pt\nint x, int y"
     , "QPoint pt\nint x, int y"
+    , "QDataStream arg__1"
     , ""
     , ""
     , "QIODevice device, char format, int quality\nString fileName, char format, int quality"
@@ -132,7 +136,7 @@ static const char * const qtscript_QImage_function_signatures[] = {
     , "QImage alphaChannel"
     , "int i, unsigned int c"
     , "int arg__1"
-    , "qreal scaleFactor"
+    , "int arg__1"
     , "int arg__1"
     , "int arg__1"
     , "QPoint arg__1"
@@ -144,6 +148,7 @@ static const char * const qtscript_QImage_function_signatures[] = {
     , ""
     , "QMatrix matrix, TransformationMode mode\nQTransform matrix, TransformationMode mode"
     , "QPoint pt\nint x, int y"
+    , "QDataStream arg__1"
 ""
 };
 
@@ -180,9 +185,11 @@ static const int qtscript_QImage_function_lengths[] = {
     , 2
     , 2
     , 0
+    , 0
     , 1
     , 2
     , 2
+    , 1
     , 0
     , 0
     , 3
@@ -204,6 +211,7 @@ static const int qtscript_QImage_function_lengths[] = {
     , 0
     , 2
     , 2
+    , 1
     , 0
 };
 
@@ -223,12 +231,13 @@ Q_DECLARE_METATYPE(QtScriptShell_QImage)
 Q_DECLARE_METATYPE(QtScriptShell_QImage*)
 Q_DECLARE_METATYPE(QImage::InvertMode)
 Q_DECLARE_METATYPE(QImage::Format)
-Q_DECLARE_METATYPE(QVector<unsigned int >)
-Q_DECLARE_METATYPE(const uchar*)
+Q_DECLARE_METATYPE(QVector<uint>)
+Q_DECLARE_METATYPE(uchar*)
 Q_DECLARE_METATYPE(QFlags<Qt::ImageConversionFlag>)
 Q_DECLARE_METATYPE(Qt::MaskMode)
 Q_DECLARE_METATYPE(Qt::GlobalColor)
 Q_DECLARE_METATYPE(QIODevice*)
+Q_DECLARE_METATYPE(QDataStream*)
 Q_DECLARE_METATYPE(Qt::AspectRatioMode)
 Q_DECLARE_METATYPE(Qt::TransformationMode)
 Q_DECLARE_METATYPE(QPaintDevice*)
@@ -335,9 +344,6 @@ static const QImage::Format qtscript_QImage_Format_values[] = {
     , QImage::Format_RGB888
     , QImage::Format_RGB444
     , QImage::Format_ARGB4444_Premultiplied
-    , QImage::Format_RGBX8888
-    , QImage::Format_RGBA8888
-    , QImage::Format_RGBA8888_Premultiplied
     , QImage::NImageFormats
 };
 
@@ -358,9 +364,6 @@ static const char * const qtscript_QImage_Format_keys[] = {
     , "Format_RGB888"
     , "Format_RGB444"
     , "Format_ARGB4444_Premultiplied"
-    , "Format_RGBX8888"
-    , "Format_RGBA8888"
-    , "Format_RGBA8888_Premultiplied"
     , "NImageFormats"
 };
 
@@ -409,7 +412,7 @@ static QScriptValue qtscript_create_QImage_Format_class(QScriptEngine *engine, Q
         qtscript_QImage_Format_valueOf, qtscript_QImage_Format_toString);
     qScriptRegisterMetaType<QImage::Format>(engine, qtscript_QImage_Format_toScriptValue,
         qtscript_QImage_Format_fromScriptValue, ctor.property(QString::fromLatin1("prototype")));
-    for (int i = 0; i < 20; ++i) {
+    for (int i = 0; i < 17; ++i) {
         clazz.setProperty(QString::fromLatin1(qtscript_QImage_Format_keys[i]),
             engine->newVariant(qVariantFromValue(qtscript_QImage_Format_values[i])),
             QScriptValue::ReadOnly | QScriptValue::Undeletable);
@@ -431,7 +434,7 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     if (context->callee().isFunction())
         _id = context->callee().data().toUInt32();
     else
-        _id = 0xBABE0000 + 51;
+        _id = 0xBABE0000 + 54;
 #endif
     Q_ASSERT((_id & 0xFFFF0000) == 0xBABE0000);
     _id &= 0x0000FFFF;
@@ -488,21 +491,21 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     case 6:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
-        unsigned int _q_result = _q_self->color(_q_arg0);
+        uint _q_result = _q_self->color(_q_arg0);
         return QScriptValue(context->engine(), _q_result);
     }
     break;
 
     case 7:
     if (context->argumentCount() == 0) {
-        QVector<unsigned int > _q_result = _q_self->colorTable();
+        QVector<uint> _q_result = _q_self->colorTable();
         return qScriptValueFromSequence(context->engine(), _q_result);
     }
     break;
 
     case 8:
     if (context->argumentCount() == 0) {
-        const uchar* _q_result = const_cast<const uchar*>(_q_self->constBits());
+        uchar* _q_result = const_cast<uchar*>(_q_self->constBits());
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
@@ -510,7 +513,7 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     case 9:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
-        const uchar* _q_result = const_cast<const uchar*>(_q_self->constScanLine(_q_arg0));
+        uchar* _q_result = const_cast<uchar*>(_q_self->constScanLine(_q_arg0));
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
@@ -735,13 +738,20 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     break;
 
     case 26:
+    if (context->argumentCount() == 0) {
+        int _q_result = _q_self->numBytes();
+        return QScriptValue(context->engine(), _q_result);
+    }
+    break;
+
+    case 27:
     if (context->argumentCount() == 0) {
         QPoint _q_result = _q_self->offset();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 27:
+    case 28:
     if (context->argumentCount() == 1) {
         QImage _q_arg0 = qscriptvalue_cast<QImage>(context->argument(0));
         bool _q_result = _q_self->operator==(_q_arg0);
@@ -749,21 +759,21 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 28:
+    case 29:
     if (context->argumentCount() == 1) {
         QPoint _q_arg0 = qscriptvalue_cast<QPoint>(context->argument(0));
-        unsigned int _q_result = _q_self->pixel(_q_arg0);
+        uint _q_result = _q_self->pixel(_q_arg0);
         return QScriptValue(context->engine(), _q_result);
     }
     if (context->argumentCount() == 2) {
         int _q_arg0 = context->argument(0).toInt32();
         int _q_arg1 = context->argument(1).toInt32();
-        unsigned int _q_result = _q_self->pixel(_q_arg0, _q_arg1);
+        uint _q_result = _q_self->pixel(_q_arg0, _q_arg1);
         return QScriptValue(context->engine(), _q_result);
     }
     break;
 
-    case 29:
+    case 30:
     if (context->argumentCount() == 1) {
         QPoint _q_arg0 = qscriptvalue_cast<QPoint>(context->argument(0));
         int _q_result = _q_self->pixelIndex(_q_arg0);
@@ -777,21 +787,29 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 30:
+    case 31:
+    if (context->argumentCount() == 1) {
+        QDataStream* _q_arg0 = qscriptvalue_cast<QDataStream*>(context->argument(0));
+        operator>>(*_q_arg0, *_q_self);
+        return context->engine()->undefinedValue();
+    }
+    break;
+
+    case 32:
     if (context->argumentCount() == 0) {
         QRect _q_result = _q_self->rect();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 31:
+    case 33:
     if (context->argumentCount() == 0) {
         QImage _q_result = _q_self->rgbSwapped();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 32:
+    case 34:
     if (context->argumentCount() == 1) {
         if (qscriptvalue_cast<QIODevice*>(context->argument(0))) {
             QIODevice* _q_arg0 = qscriptvalue_cast<QIODevice*>(context->argument(0));
@@ -855,7 +873,7 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 33:
+    case 35:
     if (context->argumentCount() == 1) {
         QSize _q_arg0 = qscriptvalue_cast<QSize>(context->argument(0));
         QImage _q_result = _q_self->scaled(_q_arg0);
@@ -905,7 +923,7 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 34:
+    case 36:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
         QImage _q_result = _q_self->scaledToHeight(_q_arg0);
@@ -919,7 +937,7 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 35:
+    case 37:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
         QImage _q_result = _q_self->scaledToWidth(_q_arg0);
@@ -933,7 +951,7 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 36:
+    case 38:
     if (context->argumentCount() == 1) {
         QImage _q_arg0 = qscriptvalue_cast<QImage>(context->argument(0));
         _q_self->setAlphaChannel(_q_arg0);
@@ -941,7 +959,7 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 37:
+    case 39:
     if (context->argumentCount() == 2) {
         int _q_arg0 = context->argument(0).toInt32();
         uint _q_arg1 = context->argument(1).toUInt32();
@@ -950,7 +968,7 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 38:
+    case 40:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
         _q_self->setColorCount(_q_arg0);
@@ -958,15 +976,7 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 39:
-    if (context->argumentCount() == 1) {
-        qreal _q_arg0 = qscriptvalue_cast<qreal>(context->argument(0));
-        _q_self->setDevicePixelRatio(_q_arg0);
-        return context->engine()->undefinedValue();
-    }
-    break;
-
-    case 40:
+    case 41:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
         _q_self->setDotsPerMeterX(_q_arg0);
@@ -974,7 +984,7 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 41:
+    case 42:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
         _q_self->setDotsPerMeterY(_q_arg0);
@@ -982,7 +992,15 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 42:
+    case 43:
+    if (context->argumentCount() == 1) {
+        int _q_arg0 = context->argument(0).toInt32();
+        _q_self->setNumColors(_q_arg0);
+        return context->engine()->undefinedValue();
+    }
+    break;
+
+    case 44:
     if (context->argumentCount() == 1) {
         QPoint _q_arg0 = qscriptvalue_cast<QPoint>(context->argument(0));
         _q_self->setOffset(_q_arg0);
@@ -990,7 +1008,7 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 43:
+    case 45:
     if (context->argumentCount() == 2) {
         QPoint _q_arg0 = qscriptvalue_cast<QPoint>(context->argument(0));
         uint _q_arg1 = context->argument(1).toUInt32();
@@ -1006,7 +1024,7 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 44:
+    case 46:
     if (context->argumentCount() == 2) {
         QString _q_arg0 = context->argument(0).toString();
         QString _q_arg1 = context->argument(1).toString();
@@ -1015,14 +1033,14 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 45:
+    case 47:
     if (context->argumentCount() == 0) {
         QSize _q_result = _q_self->size();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 46:
+    case 48:
     if (context->argumentCount() == 1) {
         QImage _q_arg0 = qscriptvalue_cast<QImage>(context->argument(0));
         _q_self->swap(_q_arg0);
@@ -1030,7 +1048,7 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 47:
+    case 49:
     if (context->argumentCount() == 0) {
         QString _q_result = _q_self->text();
         return QScriptValue(context->engine(), _q_result);
@@ -1042,14 +1060,14 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 48:
+    case 50:
     if (context->argumentCount() == 0) {
         QStringList _q_result = _q_self->textKeys();
         return qScriptValueFromSequence(context->engine(), _q_result);
     }
     break;
 
-    case 49:
+    case 51:
     if (context->argumentCount() == 1) {
         if ((qMetaTypeId<QMatrix>() == context->argument(0).toVariant().userType())) {
             QMatrix _q_arg0 = qscriptvalue_cast<QMatrix>(context->argument(0));
@@ -1078,7 +1096,7 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 50:
+    case 52:
     if (context->argumentCount() == 1) {
         QPoint _q_arg0 = qscriptvalue_cast<QPoint>(context->argument(0));
         bool _q_result = _q_self->valid(_q_arg0);
@@ -1092,10 +1110,16 @@ static QScriptValue qtscript_QImage_prototype_call(QScriptContext *context, QScr
     }
     break;
 
-    case 51: {
-    QString result;
-    QDebug d(&result);
-    d << *_q_self;
+    case 53:
+    if (context->argumentCount() == 1) {
+        QDataStream* _q_arg0 = qscriptvalue_cast<QDataStream*>(context->argument(0));
+        operator<<(*_q_arg0, *_q_self);
+        return context->engine()->undefinedValue();
+    }
+    break;
+
+    case 54: {
+    QString result = QString::fromLatin1("QImage");
     return QScriptValue(context->engine(), result);
     }
 
@@ -1217,7 +1241,7 @@ QScriptValue qtscript_create_QImage_class(QScriptEngine *engine)
     engine->setDefaultPrototype(qMetaTypeId<QImage*>(), QScriptValue());
     QScriptValue proto = engine->newVariant(qVariantFromValue((QImage*)0));
     proto.setPrototype(engine->defaultPrototype(qMetaTypeId<QPaintDevice*>()));
-    for (int i = 0; i < 52; ++i) {
+    for (int i = 0; i < 55; ++i) {
         QScriptValue fun = engine->newFunction(qtscript_QImage_prototype_call, qtscript_QImage_function_lengths[i+3]);
         fun.setData(QScriptValue(engine, uint(0xBABE0000 + i)));
         proto.setProperty(QString::fromLatin1(qtscript_QImage_function_names[i+3]),
