@@ -55,6 +55,7 @@ static const char * const qtscript_QPolygonF_function_names[] = {
     , "squeeze"
     , "startsWith"
     , "subtracted"
+    , "swap"
     , "toList"
     , "toPolygon"
     , "translate"
@@ -106,6 +107,7 @@ static const char * const qtscript_QPolygonF_function_signatures[] = {
     , ""
     , "QPointF t"
     , "QPolygonF r"
+    , "QPolygonF other"
     , ""
     , ""
     , "QPointF offset\nqreal dx, qreal dy"
@@ -157,6 +159,7 @@ static const int qtscript_QPolygonF_function_lengths[] = {
     , 0
     , 1
     , 1
+    , 1
     , 0
     , 0
     , 2
@@ -199,7 +202,7 @@ static QScriptValue qtscript_QPolygonF_prototype_call(QScriptContext *context, Q
     if (context->callee().isFunction())
         _id = context->callee().data().toUInt32();
     else
-        _id = 0xBABE0000 + 43;
+        _id = 0xBABE0000 + 44;
 #endif
     Q_ASSERT((_id & 0xFFFF0000) == 0xBABE0000);
     _id &= 0x0000FFFF;
@@ -526,20 +529,28 @@ static QScriptValue qtscript_QPolygonF_prototype_call(QScriptContext *context, Q
     break;
 
     case 36:
+    if (context->argumentCount() == 1) {
+        QPolygonF _q_arg0 = qscriptvalue_cast<QPolygonF>(context->argument(0));
+        _q_self->swap(_q_arg0);
+        return context->engine()->undefinedValue();
+    }
+    break;
+
+    case 37:
     if (context->argumentCount() == 0) {
         QList<QPointF> _q_result = _q_self->toList();
         return qScriptValueFromSequence(context->engine(), _q_result);
     }
     break;
 
-    case 37:
+    case 38:
     if (context->argumentCount() == 0) {
         QPolygon _q_result = _q_self->toPolygon();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 38:
+    case 39:
     if (context->argumentCount() == 1) {
         QPointF _q_arg0 = qscriptvalue_cast<QPointF>(context->argument(0));
         _q_self->translate(_q_arg0);
@@ -553,7 +564,7 @@ static QScriptValue qtscript_QPolygonF_prototype_call(QScriptContext *context, Q
     }
     break;
 
-    case 39:
+    case 40:
     if (context->argumentCount() == 1) {
         QPointF _q_arg0 = qscriptvalue_cast<QPointF>(context->argument(0));
         QPolygonF _q_result = _q_self->translated(_q_arg0);
@@ -567,7 +578,7 @@ static QScriptValue qtscript_QPolygonF_prototype_call(QScriptContext *context, Q
     }
     break;
 
-    case 40:
+    case 41:
     if (context->argumentCount() == 1) {
         QPolygonF _q_arg0 = qscriptvalue_cast<QPolygonF>(context->argument(0));
         QPolygonF _q_result = _q_self->united(_q_arg0);
@@ -575,7 +586,7 @@ static QScriptValue qtscript_QPolygonF_prototype_call(QScriptContext *context, Q
     }
     break;
 
-    case 41:
+    case 42:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
         QPointF _q_result = _q_self->value(_q_arg0);
@@ -589,7 +600,7 @@ static QScriptValue qtscript_QPolygonF_prototype_call(QScriptContext *context, Q
     }
     break;
 
-    case 42:
+    case 43:
     if (context->argumentCount() == 1) {
         QDataStream* _q_arg0 = qscriptvalue_cast<QDataStream*>(context->argument(0));
         operator<<(*_q_arg0, *_q_self);
@@ -597,7 +608,7 @@ static QScriptValue qtscript_QPolygonF_prototype_call(QScriptContext *context, Q
     }
     break;
 
-    case 43: {
+    case 44: {
     QString result;
     QDebug d(&result);
     d << *_q_self;
@@ -678,7 +689,7 @@ QScriptValue qtscript_create_QPolygonF_class(QScriptEngine *engine)
 {
     engine->setDefaultPrototype(qMetaTypeId<QPolygonF*>(), QScriptValue());
     QScriptValue proto = engine->newVariant(qVariantFromValue((QPolygonF*)0));
-    for (int i = 0; i < 44; ++i) {
+    for (int i = 0; i < 45; ++i) {
         QScriptValue fun = engine->newFunction(qtscript_QPolygonF_prototype_call, qtscript_QPolygonF_function_lengths[i+2]);
         fun.setData(QScriptValue(engine, uint(0xBABE0000 + i)));
         proto.setProperty(QString::fromLatin1(qtscript_QPolygonF_function_names[i+2]),
