@@ -51,6 +51,7 @@ static const char * const qtscript_QSslSocket_function_names[] = {
     , "peerCertificateChain"
     , "peerVerifyDepth"
     , "peerVerifyMode"
+    , "peerVerifyName"
     , "privateKey"
     , "protocol"
     , "sessionCipher"
@@ -59,6 +60,7 @@ static const char * const qtscript_QSslSocket_function_names[] = {
     , "setLocalCertificate"
     , "setPeerVerifyDepth"
     , "setPeerVerifyMode"
+    , "setPeerVerifyName"
     , "setPrivateKey"
     , "setProtocol"
     , "setSslConfiguration"
@@ -99,11 +101,13 @@ static const char * const qtscript_QSslSocket_function_signatures[] = {
     , ""
     , ""
     , ""
+    , ""
     , "List certificates"
     , "List ciphers\nString ciphers"
     , "QSslCertificate certificate\nString fileName, EncodingFormat format"
     , "int depth"
     , "PeerVerifyMode mode"
+    , "String hostName"
     , "QSslKey key\nString fileName, KeyAlgorithm algorithm, EncodingFormat format, QByteArray passPhrase"
     , "SslProtocol protocol"
     , "QSslConfiguration config"
@@ -144,11 +148,13 @@ static const int qtscript_QSslSocket_function_lengths[] = {
     , 0
     , 0
     , 0
+    , 0
     , 1
     , 1
     , 2
     , 1
     , 1
+    , 1
     , 4
     , 1
     , 1
@@ -355,7 +361,7 @@ static QScriptValue qtscript_QSslSocket_prototype_call(QScriptContext *context,
     if (context->callee().isFunction())
         _id = context->callee().data().toUInt32();
     else
-        _id = 0xBABE0000 + 29;
+        _id = 0xBABE0000 + 31;
 #endif
     Q_ASSERT((_id & 0xFFFF0000) == 0xBABE0000);
     _id &= 0x0000FFFF;
@@ -527,26 +533,33 @@ static QScriptValue qtscript_QSslSocket_prototype_call(QScriptContext *context,
 
     case 15:
     if (context->argumentCount() == 0) {
-        QSslKey _q_result = _q_self->privateKey();
-        return qScriptValueFromValue(context->engine(), _q_result);
+        QString _q_result = _q_self->peerVerifyName();
+        return QScriptValue(context->engine(), _q_result);
     }
     break;
 
     case 16:
     if (context->argumentCount() == 0) {
-        QSsl::SslProtocol _q_result = _q_self->protocol();
+        QSslKey _q_result = _q_self->privateKey();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
     case 17:
     if (context->argumentCount() == 0) {
-        QSslCipher _q_result = _q_self->sessionCipher();
+        QSsl::SslProtocol _q_result = _q_self->protocol();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
     case 18:
+    if (context->argumentCount() == 0) {
+        QSslCipher _q_result = _q_self->sessionCipher();
+        return qScriptValueFromValue(context->engine(), _q_result);
+    }
+    break;
+
+    case 19:
     if (context->argumentCount() == 1) {
         QList<QSslCertificate> _q_arg0;
         qScriptValueToSequence(context->argument(0), _q_arg0);
@@ -555,7 +568,7 @@ static QScriptValue qtscript_QSslSocket_prototype_call(QScriptContext *context,
     }
     break;
 
-    case 19:
+    case 20:
     if (context->argumentCount() == 1) {
         if (context->argument(0).isArray()) {
             QList<QSslCipher> _q_arg0;
@@ -570,7 +583,7 @@ static QScriptValue qtscript_QSslSocket_prototype_call(QScriptContext *context,
     }
     break;
 
-    case 20:
+    case 21:
     if (context->argumentCount() == 1) {
         if ((qMetaTypeId<QSslCertificate>() == context->argument(0).toVariant().userType())) {
             QSslCertificate _q_arg0 = qscriptvalue_cast<QSslCertificate>(context->argument(0));
@@ -590,7 +603,7 @@ static QScriptValue qtscript_QSslSocket_prototype_call(QScriptContext *context,
     }
     break;
 
-    case 21:
+    case 22:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
         _q_self->setPeerVerifyDepth(_q_arg0);
@@ -598,7 +611,7 @@ static QScriptValue qtscript_QSslSocket_prototype_call(QScriptContext *context,
     }
     break;
 
-    case 22:
+    case 23:
     if (context->argumentCount() == 1) {
         QSslSocket::PeerVerifyMode _q_arg0 = qscriptvalue_cast<QSslSocket::PeerVerifyMode>(context->argument(0));
         _q_self->setPeerVerifyMode(_q_arg0);
@@ -606,7 +619,15 @@ static QScriptValue qtscript_QSslSocket_prototype_call(QScriptContext *context,
     }
     break;
 
-    case 23:
+    case 24:
+    if (context->argumentCount() == 1) {
+        QString _q_arg0 = context->argument(0).toString();
+        _q_self->setPeerVerifyName(_q_arg0);
+        return context->engine()->undefinedValue();
+    }
+    break;
+
+    case 25:
     if (context->argumentCount() == 1) {
         if ((qMetaTypeId<QSslKey>() == context->argument(0).toVariant().userType())) {
             QSslKey _q_arg0 = qscriptvalue_cast<QSslKey>(context->argument(0));
@@ -641,7 +662,7 @@ static QScriptValue qtscript_QSslSocket_prototype_call(QScriptContext *context,
     }
     break;
 
-    case 24:
+    case 26:
     if (context->argumentCount() == 1) {
         QSsl::SslProtocol _q_arg0 = qscriptvalue_cast<QSsl::SslProtocol>(context->argument(0));
         _q_self->setProtocol(_q_arg0);
@@ -649,7 +670,7 @@ static QScriptValue qtscript_QSslSocket_prototype_call(QScriptContext *context,
     }
     break;
 
-    case 25:
+    case 27:
     if (context->argumentCount() == 1) {
         QSslConfiguration _q_arg0 = qscriptvalue_cast<QSslConfiguration>(context->argument(0));
         _q_self->setSslConfiguration(_q_arg0);
@@ -657,21 +678,21 @@ static QScriptValue qtscript_QSslSocket_prototype_call(QScriptContext *context,
     }
     break;
 
-    case 26:
+    case 28:
     if (context->argumentCount() == 0) {
         QSslConfiguration _q_result = _q_self->sslConfiguration();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
 
-    case 27:
+    case 29:
     if (context->argumentCount() == 0) {
         QList<QSslError> _q_result = _q_self->sslErrors();
         return qScriptValueFromSequence(context->engine(), _q_result);
     }
     break;
 
-    case 28:
+    case 30:
     if (context->argumentCount() == 0) {
         bool _q_result = _q_self->waitForEncrypted();
         return QScriptValue(context->engine(), _q_result);
@@ -683,7 +704,7 @@ static QScriptValue qtscript_QSslSocket_prototype_call(QScriptContext *context,
     }
     break;
 
-    case 29: {
+    case 31: {
     QString result = QString::fromLatin1("QSslSocket");
     return QScriptValue(context->engine(), result);
     }
@@ -832,7 +853,7 @@ QScriptValue qtscript_create_QSslSocket_class(QScriptEngine *engine)
     engine->setDefaultPrototype(qMetaTypeId<QSslSocket*>(), QScriptValue());
     QScriptValue proto = engine->newVariant(qVariantFromValue((QSslSocket*)0));
     proto.setPrototype(engine->defaultPrototype(qMetaTypeId<QTcpSocket*>()));
-    for (int i = 0; i < 30; ++i) {
+    for (int i = 0; i < 32; ++i) {
         QScriptValue fun = engine->newFunction(qtscript_QSslSocket_prototype_call, qtscript_QSslSocket_function_lengths[i+10]);
         fun.setData(QScriptValue(engine, uint(0xBABE0000 + i)));
         proto.setProperty(QString::fromLatin1(qtscript_QSslSocket_function_names[i+10]),
