@@ -4,7 +4,6 @@
 #include <qtcpserver.h>
 
 #include <QtScript/qscriptvalue.h>
-#include <__package_shared.h>
 
 class QtScriptShell_QTcpServer : public QTcpServer
 {
@@ -17,6 +16,7 @@ public:
     bool  event(QEvent*  arg__1);
     bool  eventFilter(QObject*  arg__1, QEvent*  arg__2);
     bool  hasPendingConnections() const;
+    void incomingConnection(int  handle);
     QTcpSocket*  nextPendingConnection();
     void timerEvent(QTimerEvent*  arg__1);
 
