@@ -4,10 +4,10 @@
 #include <QtCore/QStringList>
 #include <QtCore/QDebug>
 #include <qmetaobject.h>
+#include <__package_shared.h>
 
 #include <qpolygon.h>
 #include <QVariant>
-#include <qdatastream.h>
 #include <qlist.h>
 #include <qpoint.h>
 #include <qpolygon.h>
@@ -37,6 +37,7 @@ static const char * const qtscript_QPolygon_function_names[] = {
     , "isSharedWith"
     , "last"
     , "lastIndexOf"
+    , "length"
     , "mid"
     , "equals"
     , "pop_back"
@@ -44,8 +45,10 @@ static const char * const qtscript_QPolygon_function_names[] = {
     , "prepend"
     , "push_back"
     , "push_front"
-    , "readFrom"
     , "remove"
+    , "removeAt"
+    , "removeFirst"
+    , "removeLast"
     , "replace"
     , "reserve"
     , "resize"
@@ -54,12 +57,15 @@ static const char * const qtscript_QPolygon_function_names[] = {
     , "squeeze"
     , "startsWith"
     , "subtracted"
+    , "swap"
+    , "takeAt"
+    , "takeFirst"
+    , "takeLast"
     , "toList"
     , "translate"
     , "translated"
     , "united"
     , "value"
-    , "writeTo"
     , "toString"
 };
 
@@ -86,15 +92,18 @@ static const char * const qtscript_QPolygon_function_signatures[] = {
     , "List other"
     , ""
     , "QPoint t, int from"
-    , "int pos, int length"
+    , ""
+    , "int pos, int len"
     , "List v"
     , ""
     , ""
     , "QPoint t"
     , "QPoint t"
     , "QPoint t"
-    , "QDataStream stream"
     , "int i\nint i, int n"
+    , "int i"
+    , ""
+    , ""
     , "int i, QPoint t"
     , "int size"
     , "int size"
@@ -103,12 +112,15 @@ static const char * const qtscript_QPolygon_function_signatures[] = {
     , ""
     , "QPoint t"
     , "QPolygon r"
+    , "QPolygon other"
+    , "int i"
+    , ""
+    , ""
     , ""
     , "QPoint offset\nint dx, int dy"
     , "QPoint offset\nint dx, int dy"
     , "QPolygon r"
     , "int i\nint i, QPoint defaultValue"
-    , "QDataStream stream"
 ""
 };
 
@@ -135,6 +147,7 @@ static const int qtscript_QPolygon_function_lengths[] = {
     , 1
     , 0
     , 2
+    , 0
     , 2
     , 1
     , 0
@@ -142,8 +155,10 @@ static const int qtscript_QPolygon_function_lengths[] = {
     , 1
     , 1
     , 1
-    , 1
     , 2
+    , 1
+    , 0
+    , 0
     , 2
     , 1
     , 1
@@ -152,12 +167,15 @@ static const int qtscript_QPolygon_function_lengths[] = {
     , 0
     , 1
     , 1
+    , 1
+    , 1
+    , 0
+    , 0
     , 0
     , 2
     , 2
     , 1
     , 2
-    , 1
     , 0
 };
 
@@ -174,9 +192,8 @@ static QScriptValue qtscript_QPolygon_throw_ambiguity_error_helper(
 
 Q_DECLARE_METATYPE(QPolygon*)
 Q_DECLARE_METATYPE(Qt::FillRule)
-Q_DECLARE_METATYPE(QVector<QPoint>)
-Q_DECLARE_METATYPE(QDataStream*)
-Q_DECLARE_METATYPE(QList<QPoint>)
+Q_DECLARE_METATYPE(QVector<QPoint >)
+Q_DECLARE_METATYPE(QList<QPoint >)
 
 //
 // QPolygon
@@ -192,7 +209,7 @@ static QScriptValue qtscript_QPolygon_prototype_call(QScriptContext *context, QS
     if (context->callee().isFunction())
         _id = context->callee().data().toUInt32();
     else
-        _id = 0xBABE0000 + 41;
+        _id = 0xBABE0000 + 47;
 #endif
     Q_ASSERT((_id & 0xFFFF0000) == 0xBABE0000);
     _id &= 0x0000FFFF;
@@ -215,7 +232,7 @@ static QScriptValue qtscript_QPolygon_prototype_call(QScriptContext *context, QS
     case 1:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
-        QPoint _q_result = _q_self->at(_q_arg0);
+        const QPoint& _q_result = _q_self->at(_q_arg0);
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
@@ -288,20 +305,20 @@ static QScriptValue qtscript_QPolygon_prototype_call(QScriptContext *context, QS
     case 10:
     if (context->argumentCount() == 1) {
         QPoint _q_arg0 = qscriptvalue_cast<QPoint>(context->argument(0));
-        QVector<QPoint> _q_result = _q_self->fill(_q_arg0);
+        QVector<QPoint >& _q_result = _q_self->fill(_q_arg0);
         return qScriptValueFromSequence(context->engine(), _q_result);
     }
     if (context->argumentCount() == 2) {
         QPoint _q_arg0 = qscriptvalue_cast<QPoint>(context->argument(0));
         int _q_arg1 = context->argument(1).toInt32();
-        QVector<QPoint> _q_result = _q_self->fill(_q_arg0, _q_arg1);
+        QVector<QPoint >& _q_result = _q_self->fill(_q_arg0, _q_arg1);
         return qScriptValueFromSequence(context->engine(), _q_result);
     }
     break;
 
     case 11:
     if (context->argumentCount() == 0) {
-        QPoint _q_result = _q_self->first();
+        const QPoint& _q_result = _q_self->first();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
@@ -346,7 +363,7 @@ static QScriptValue qtscript_QPolygon_prototype_call(QScriptContext *context, QS
 
     case 16:
     if (context->argumentCount() == 0) {
-        QPoint _q_result = _q_self->last();
+        const QPoint& _q_result = _q_self->last();
         return qScriptValueFromValue(context->engine(), _q_result);
     }
     break;
@@ -366,20 +383,27 @@ static QScriptValue qtscript_QPolygon_prototype_call(QScriptContext *context, QS
     break;
 
     case 18:
+    if (context->argumentCount() == 0) {
+        int _q_result = _q_self->length();
+        return QScriptValue(context->engine(), _q_result);
+    }
+    break;
+
+    case 19:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
-        QVector<QPoint> _q_result = _q_self->mid(_q_arg0);
+        QVector<QPoint > _q_result = _q_self->mid(_q_arg0);
         return qScriptValueFromSequence(context->engine(), _q_result);
     }
     if (context->argumentCount() == 2) {
         int _q_arg0 = context->argument(0).toInt32();
         int _q_arg1 = context->argument(1).toInt32();
-        QVector<QPoint> _q_result = _q_self->mid(_q_arg0, _q_arg1);
+        QVector<QPoint > _q_result = _q_self->mid(_q_arg0, _q_arg1);
         return qScriptValueFromSequence(context->engine(), _q_result);
     }
     break;
 
-    case 19:
+    case 20:
     if (context->argumentCount() == 1) {
         QVector<QPoint> _q_arg0;
         qScriptValueToSequence(context->argument(0), _q_arg0);
@@ -388,32 +412,24 @@ static QScriptValue qtscript_QPolygon_prototype_call(QScriptContext *context, QS
     }
     break;
 
-    case 20:
+    case 21:
     if (context->argumentCount() == 0) {
         _q_self->pop_back();
         return context->engine()->undefinedValue();
     }
     break;
 
-    case 21:
+    case 22:
     if (context->argumentCount() == 0) {
         _q_self->pop_front();
         return context->engine()->undefinedValue();
     }
     break;
 
-    case 22:
-    if (context->argumentCount() == 1) {
-        QPoint _q_arg0 = qscriptvalue_cast<QPoint>(context->argument(0));
-        _q_self->prepend(_q_arg0);
-        return context->engine()->undefinedValue();
-    }
-    break;
-
     case 23:
     if (context->argumentCount() == 1) {
         QPoint _q_arg0 = qscriptvalue_cast<QPoint>(context->argument(0));
-        _q_self->push_back(_q_arg0);
+        _q_self->prepend(_q_arg0);
         return context->engine()->undefinedValue();
     }
     break;
@@ -421,15 +437,15 @@ static QScriptValue qtscript_QPolygon_prototype_call(QScriptContext *context, QS
     case 24:
     if (context->argumentCount() == 1) {
         QPoint _q_arg0 = qscriptvalue_cast<QPoint>(context->argument(0));
-        _q_self->push_front(_q_arg0);
+        _q_self->push_back(_q_arg0);
         return context->engine()->undefinedValue();
     }
     break;
 
     case 25:
     if (context->argumentCount() == 1) {
-        QDataStream* _q_arg0 = qscriptvalue_cast<QDataStream*>(context->argument(0));
-        operator>>(*_q_arg0, *_q_self);
+        QPoint _q_arg0 = qscriptvalue_cast<QPoint>(context->argument(0));
+        _q_self->push_front(_q_arg0);
         return context->engine()->undefinedValue();
     }
     break;
@@ -449,6 +465,28 @@ static QScriptValue qtscript_QPolygon_prototype_call(QScriptContext *context, QS
     break;
 
     case 27:
+    if (context->argumentCount() == 1) {
+        int _q_arg0 = context->argument(0).toInt32();
+        _q_self->removeAt(_q_arg0);
+        return context->engine()->undefinedValue();
+    }
+    break;
+
+    case 28:
+    if (context->argumentCount() == 0) {
+        _q_self->removeFirst();
+        return context->engine()->undefinedValue();
+    }
+    break;
+
+    case 29:
+    if (context->argumentCount() == 0) {
+        _q_self->removeLast();
+        return context->engine()->undefinedValue();
+    }
+    break;
+
+    case 30:
     if (context->argumentCount() == 2) {
         int _q_arg0 = context->argument(0).toInt32();
         QPoint _q_arg1 = qscriptvalue_cast<QPoint>(context->argument(1));
@@ -457,7 +495,7 @@ static QScriptValue qtscript_QPolygon_prototype_call(QScriptContext *context, QS
     }
     break;
 
-    case 28:
+    case 31:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
         _q_self->reserve(_q_arg0);
@@ -465,7 +503,7 @@ static QScriptValue qtscript_QPolygon_prototype_call(QScriptContext *context, QS
     }
     break;
 
-    case 29:
+    case 32:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
         _q_self->resize(_q_arg0);
@@ -473,7 +511,7 @@ static QScriptValue qtscript_QPolygon_prototype_call(QScriptContext *context, QS
     }
     break;
 
-    case 30:
+    case 33:
     if (context->argumentCount() == 1) {
         bool _q_arg0 = context->argument(0).toBoolean();
         _q_self->setSharable(_q_arg0);
@@ -481,21 +519,21 @@ static QScriptValue qtscript_QPolygon_prototype_call(QScriptContext *context, QS
     }
     break;
 
-    case 31:
+    case 34:
     if (context->argumentCount() == 0) {
         int _q_result = _q_self->size();
         return QScriptValue(context->engine(), _q_result);
     }
     break;
 
-    case 32:
+    case 35:
     if (context->argumentCount() == 0) {
         _q_self->squeeze();
         return context->engine()->undefinedValue();
     }
     break;
 
-    case 33:
+    case 36:
     if (context->argumentCount() == 1) {
         QPoint _q_arg0 = qscriptvalue_cast<QPoint>(context->argument(0));
         bool _q_result = _q_self->startsWith(_q_arg0);
@@ -503,7 +541,7 @@ static QScriptValue qtscript_QPolygon_prototype_call(QScriptContext *context, QS
     }
     break;
 
-    case 34:
+    case 37:
     if (context->argumentCount() == 1) {
         QPolygon _q_arg0 = qscriptvalue_cast<QPolygon>(context->argument(0));
         QPolygon _q_result = _q_self->subtracted(_q_arg0);
@@ -511,14 +549,44 @@ static QScriptValue qtscript_QPolygon_prototype_call(QScriptContext *context, QS
     }
     break;
 
-    case 35:
+    case 38:
+    if (context->argumentCount() == 1) {
+        QPolygon _q_arg0 = qscriptvalue_cast<QPolygon>(context->argument(0));
+        _q_self->swap(_q_arg0);
+        return context->engine()->undefinedValue();
+    }
+    break;
+
+    case 39:
+    if (context->argumentCount() == 1) {
+        int _q_arg0 = context->argument(0).toInt32();
+        QPoint _q_result = _q_self->takeAt(_q_arg0);
+        return qScriptValueFromValue(context->engine(), _q_result);
+    }
+    break;
+
+    case 40:
     if (context->argumentCount() == 0) {
-        QList<QPoint> _q_result = _q_self->toList();
+        QPoint _q_result = _q_self->takeFirst();
+        return qScriptValueFromValue(context->engine(), _q_result);
+    }
+    break;
+
+    case 41:
+    if (context->argumentCount() == 0) {
+        QPoint _q_result = _q_self->takeLast();
+        return qScriptValueFromValue(context->engine(), _q_result);
+    }
+    break;
+
+    case 42:
+    if (context->argumentCount() == 0) {
+        QList<QPoint > _q_result = _q_self->toList();
         return qScriptValueFromSequence(context->engine(), _q_result);
     }
     break;
 
-    case 36:
+    case 43:
     if (context->argumentCount() == 1) {
         QPoint _q_arg0 = qscriptvalue_cast<QPoint>(context->argument(0));
         _q_self->translate(_q_arg0);
@@ -532,7 +600,7 @@ static QScriptValue qtscript_QPolygon_prototype_call(QScriptContext *context, QS
     }
     break;
 
-    case 37:
+    case 44:
     if (context->argumentCount() == 1) {
         QPoint _q_arg0 = qscriptvalue_cast<QPoint>(context->argument(0));
         QPolygon _q_result = _q_self->translated(_q_arg0);
@@ -546,7 +614,7 @@ static QScriptValue qtscript_QPolygon_prototype_call(QScriptContext *context, QS
     }
     break;
 
-    case 38:
+    case 45:
     if (context->argumentCount() == 1) {
         QPolygon _q_arg0 = qscriptvalue_cast<QPolygon>(context->argument(0));
         QPolygon _q_result = _q_self->united(_q_arg0);
@@ -554,7 +622,7 @@ static QScriptValue qtscript_QPolygon_prototype_call(QScriptContext *context, QS
     }
     break;
 
-    case 39:
+    case 46:
     if (context->argumentCount() == 1) {
         int _q_arg0 = context->argument(0).toInt32();
         QPoint _q_result = _q_self->value(_q_arg0);
@@ -568,15 +636,7 @@ static QScriptValue qtscript_QPolygon_prototype_call(QScriptContext *context, QS
     }
     break;
 
-    case 40:
-    if (context->argumentCount() == 1) {
-        QDataStream* _q_arg0 = qscriptvalue_cast<QDataStream*>(context->argument(0));
-        operator<<(*_q_arg0, *_q_self);
-        return context->engine()->undefinedValue();
-    }
-    break;
-
-    case 41: {
+    case 47: {
     QString result;
     QDebug d(&result);
     d << *_q_self;
@@ -641,7 +701,7 @@ static QScriptValue qtscript_QPolygon_static_call(QScriptContext *context, QScri
     if (context->argumentCount() == 1) {
         QList<QPoint> _q_arg0;
         qScriptValueToSequence(context->argument(0), _q_arg0);
-        QVector<QPoint> _q_result = QPolygon::fromList(_q_arg0);
+        QVector<QPoint > _q_result = QPolygon::fromList(_q_arg0);
         return qScriptValueFromSequence(context->engine(), _q_result);
     }
     break;
@@ -658,7 +718,7 @@ QScriptValue qtscript_create_QPolygon_class(QScriptEngine *engine)
 {
     engine->setDefaultPrototype(qMetaTypeId<QPolygon*>(), QScriptValue());
     QScriptValue proto = engine->newVariant(qVariantFromValue((QPolygon*)0));
-    for (int i = 0; i < 42; ++i) {
+    for (int i = 0; i < 48; ++i) {
         QScriptValue fun = engine->newFunction(qtscript_QPolygon_prototype_call, qtscript_QPolygon_function_lengths[i+2]);
         fun.setData(QScriptValue(engine, uint(0xBABE0000 + i)));
         proto.setProperty(QString::fromLatin1(qtscript_QPolygon_function_names[i+2]),
