@@ -42,7 +42,7 @@ struct QMetaTypeId< QMap<int,QVariant > > \
     } \
 };
 Q_DECLARE_METATYPE(QFlags<Qt::MatchFlag>)
-Q_DECLARE_METATYPE(QList<QModelIndex >)
+//Q_DECLARE_METATYPE(QList<QModelIndex >)
 Q_DECLARE_METATYPE(QMimeData*)
 template <> \
 struct QMetaTypeId< QHash<int,QByteArray > > \
