@@ -69,8 +69,8 @@ Q_DECLARE_METATYPE(QPoint*)
 Q_DECLARE_METATYPE(QPaintDevice*)
 Q_DECLARE_METATYPE(QResizeEvent*)
 Q_DECLARE_METATYPE(QAbstractItemView::ScrollHint)
-Q_DECLARE_METATYPE(QList<QModelIndex >)
-Q_DECLARE_METATYPE(QItemSelection)
+//Q_DECLARE_METATYPE(QList<QModelIndex >)
+//Q_DECLARE_METATYPE(QItemSelection)
 Q_DECLARE_METATYPE(const QEvent*)
 Q_DECLARE_METATYPE(QFlags<QItemSelectionModel::SelectionFlag>)
 Q_DECLARE_METATYPE(QAbstractItemModel*)
