@@ -16,17 +16,19 @@
  * You should have received a copy of the GNU General Public License
  * along with QCAD.
  */
-#include <QtDebug>
 #include <QApplication>
 #include <QColor>
-#include <QCoreApplication>
+#include <QDir>
 #include <QFileInfo>
-#include <QFrame>
+#include <QFont>
+#include <QPalette>
 #include <QPrinterInfo>
+#include <QSettings>
 #include <QString>
 #include <QStringList>
 #include <QSysInfo>
 #include <QTranslator>
+#include <QDebug>
 
 #if QT_VERSION >= 0x050000
 #  include <QWindow>
@@ -35,9 +37,10 @@
 #  include <QDesktopServices>
 #endif
 
-#include "RDebug.h"
 #include "RMath.h"
+#include "RS.h"
 #include "RSettings.h"
+#include "RUnit.h"
 #include "RVersion.h"
 
 #ifdef Q_OS_MAC
@@ -60,6 +63,11 @@ RColor* RSettings::startReferencePointColor = NULL;
 RColor* RSettings::endReferencePointColor = NULL;
 RColor* RSettings::secondaryReferencePointColor = NULL;
 RColor* RSettings::tertiaryReferencePointColor = NULL;
+RColor* RSettings::crossHairColor = NULL;
+RColor* RSettings::crossHairColorInactive = NULL;
+RColor* RSettings::gridColor = NULL;
+RColor* RSettings::metaGridColor = NULL;
+RColor* RSettings::originColor = NULL;
 int RSettings::darkMode = -1;
 int RSettings::darkGuiBackground = -1;
 int RSettings::snapRange = -1;
@@ -73,6 +81,7 @@ int RSettings::highResolutionGraphicsView = -1;
 int RSettings::previewEntities = -1;
 int RSettings::limitZoomAndScroll = -1;
 int RSettings::autoScaleLinetypePattern = -1;
+int RSettings::applyLineweightToPoints = -1;
 int RSettings::useSecondarySelectionColor = -1;
 int RSettings::mouseThreshold = -1;
 int RSettings::positionByMousePress = -1;
@@ -91,10 +100,17 @@ int RSettings::ignoreBlockReferencePoint = -1;
 int RSettings::ignoreAllReferencePoints = -1;
 int RSettings::referencePointSize = -1;
 int RSettings::referencePointShape = -1;
+int RSettings::maxReferencePointEntities = -1;
+int RSettings::maxReferencePointEntitiesDisplay = -1;
 int RSettings::propertyEditorShowOnRequest = -1;
-QString RSettings::polarCoordinateSeparator = QString::null;
-QString RSettings::cartesianCoordinateSeparator = QString::null;
-QString RSettings::relativeCoordinatePrefix = QString::null;
+int RSettings::simpleTextAlignLeft = -1;
+int RSettings::renderThinPolylines1px = -1;
+int RSettings::maxHatchTime = -1;
+int RSettings::maxHatchComplexity = -1;
+double RSettings::devicePixelRatio = -1.0;
+QString RSettings::polarCoordinateSeparator = QString();
+QString RSettings::cartesianCoordinateSeparator = QString();
+QString RSettings::relativeCoordinatePrefix = QString();
 QStringList RSettings::recentFiles;
 QLocale* RSettings::numberLocale = NULL;
 QString RSettings::applicationNameOverride;
@@ -132,18 +148,36 @@ QString RSettings::getAppId() {
  * \return Device pixel ratio of the display. Usually 1 or 2 (for retina/high res displays).
  */
 double RSettings::getDevicePixelRatio() {
+    if (devicePixelRatio>0.0) {
+        return devicePixelRatio;
+    }
+
     // DPR can be overridden in settings:
-    int dpr = RSettings::getIntValue("Appearance/DevicePixelRatio", 0);
-    if (dpr>0) {
-        return dpr;
+    devicePixelRatio = RSettings::getIntValue("Appearance/DevicePixelRatio", -1.0);
+    if (devicePixelRatio>0.0) {
+        return devicePixelRatio;
     }
 
 #if QT_VERSION >= 0x050000
-    QWindow* window = QGuiApplication::focusWindow();
-    if (window!=NULL) {
-        return window->devicePixelRatio();
+//    QWindow* window = QGuiApplication::focusWindow();
+//    if (window!=NULL) {
+//        return window->devicePixelRatio();
+//    }
+    QWindowList windowList = QGuiApplication::topLevelWindows();
+    for (int i=0; i<windowList.length(); i++) {
+        QWindow* window = windowList[i];
+        if (window->type()==Qt::Window) {
+            devicePixelRatio = window->devicePixelRatio();
+            return devicePixelRatio;
+        }
     }
-    return qApp->devicePixelRatio();
+
+//    QWindow* window = QGuiApplication::focusWindow();
+//    if (window!=NULL) {
+//        return window->devicePixelRatio();
+//    }
+    devicePixelRatio = qApp->devicePixelRatio();
+    return devicePixelRatio;
 #else
     return 1.0;
 #endif
@@ -464,13 +498,26 @@ QString RSettings::getCacheLocation() {
  * \return Standard path for user data.
  */
 QString RSettings::getDataLocation() {
-#if QT_VERSION >= 0x050000
+#if QT_VERSION >= 0x060000
+    return RSettings::getStandardLocation(QStandardPaths::AppDataLocation);
+#elif QT_VERSION >= 0x050000
     return RSettings::getStandardLocation(QStandardPaths::DataLocation);
 #else
     return RSettings::getStandardLocation(QDesktopServices::DataLocation);
 #endif
 }
 
+/**
+ * \return Path for local plugins, independent of application name set by a plugin.
+ */
+QString RSettings::getPluginsLocation() {
+    QString appName = QCoreApplication::applicationName();
+    QCoreApplication::setApplicationName("QCAD");
+    QString ret = RSettings::getDataLocation() + "/plugins";
+    QCoreApplication::setApplicationName(appName);
+    return ret;
+}
+
 /**
  * \return Standard path for temporary files.
  */
@@ -597,20 +644,22 @@ void RSettings::loadTranslations(const QString& module, const QStringList& dirs)
     QString locale = RSettings::getLocale();
 
     QStringList translationsDirs = dirs;
-    if (translationsDirs.isEmpty()) {
-        translationsDirs = RS::getDirectoryList("ts");
-    }
+    translationsDirs.append(RS::getDirectoryList("ts"));
 
+    // prioritize user provided translations in application data directory over standard translations:
     QTranslator* translator = new QTranslator(qApp);
-    for (int i=0; i<translationsDirs.size(); ++i) {
+    for (int i=translationsDirs.size()-1; i>=0; --i) {
         QString name = module + "_" + locale;
+        if (!QFileInfo(translationsDirs[i] + "/" + name + ".qm").exists()) {
+            continue;
+        }
         if (translator->load(name, translationsDirs[i])) {
             QCoreApplication::installTranslator(translator);
             break;
         }
         else {
             if (locale!="en") {
-                qWarning() << "Cannot load translation:" << name;
+                qWarning() << "Cannot load translation:" << name << " from: " << translationsDirs[i];
             }
         }
     }
@@ -733,7 +782,7 @@ QFont RSettings::getRulerFont() {
     if (rulerFont==NULL) {
         // get application's default font (pixel size is -1, point size e.g. 10pt):
         QFont font;
-        font.setPointSize(9*getDevicePixelRatio());
+        font.setPointSize(9);
         rulerFont = new QFont(getValue("GraphicsViewFonts/Ruler", font).value<QFont>());
     }
     return *rulerFont;
@@ -751,7 +800,7 @@ QFont RSettings::getSnapLabelFont() {
     if (snapLabelFont==NULL) {
         // get application's default font (pixel size is -1, point size e.g. 10pt):
         QFont font;
-        font.setPointSize(9);
+        font.setPointSize(11);
         snapLabelFont = new QFont(getValue("GraphicsViewFonts/SnapLabel", font).value<QFont>());
     }
     return *snapLabelFont;
@@ -779,7 +828,8 @@ QFont RSettings::getStatusBarFont() {
 
 RColor RSettings::getSelectionColor() {
     if (selectionColor==NULL) {
-        selectionColor = new RColor(getColor("GraphicsViewColors/SelectionColor", RColor(164,70,70,128)));
+        //selectionColor = new RColor(getColor("GraphicsViewColors/SelectionColor", RColor(164,70,70,128)));
+        selectionColor = new RColor(getColor("GraphicsViewColors/SelectionColor", RColor(209,90,90,128)));
     }
     return *selectionColor;
 }
@@ -819,6 +869,44 @@ RColor RSettings::getTertiaryReferencePointColor() {
     return *tertiaryReferencePointColor;
 }
 
+RColor RSettings::getCrossHairColor() {
+    if (crossHairColor==NULL) {
+        crossHairColor = new RColor(getColor("GraphicsViewColors/CrosshairColor", RColor(255,194,0,192)));
+    }
+    return *crossHairColor;
+}
+
+RColor RSettings::getCrossHairColorInactive() {
+    if (crossHairColorInactive==NULL) {
+        crossHairColorInactive = new RColor(getColor("GraphicsViewColors/CrosshairColorInactive", RColor(108,79,0,192)));
+    }
+    return *crossHairColorInactive;
+}
+
+RColor RSettings::getGridColor() {
+    if (gridColor==NULL) {
+        gridColor = new RColor(getColor("GraphicsViewColors/GridColor", RColor(192,192,192,192)));
+
+    }
+    return *gridColor;
+}
+
+RColor RSettings::getMetaGridColor() {
+    if (metaGridColor==NULL) {
+        metaGridColor = new RColor(getColor("GraphicsViewColors/MetaGridColor", RColor(192,192,192,64)));
+
+    }
+    return *metaGridColor;
+}
+
+RColor RSettings::getOriginColor() {
+    if (originColor==NULL) {
+        originColor = new RColor(getColor("GraphicsViewColors/OriginColor", RColor(255,0,0,192)));
+
+    }
+    return *originColor;
+}
+
 bool RSettings::getAutoScaleGrid() {
     return getValue("GraphicsView/AutoScaleGrid", true).toBool();
 }
@@ -958,6 +1046,26 @@ int RSettings::getReferencePointShape() {
     return referencePointShape;
 }
 
+/**
+ * \return Max reference points to use.
+ */
+int RSettings::getMaxReferencePointEntities() {
+    if (maxReferencePointEntities==-1) {
+        maxReferencePointEntities = getIntValue("GraphicsView/MaxReferencePointEntities", 1000);
+    }
+    return maxReferencePointEntities;
+}
+
+/**
+ * \return Max reference points to display.
+ */
+int RSettings::getMaxReferencePointEntitiesDisplay() {
+    if (maxReferencePointEntitiesDisplay==-1) {
+        maxReferencePointEntitiesDisplay = getIntValue("GraphicsView/MaxReferencePointEntitiesDisplay", 1000);
+    }
+    return maxReferencePointEntitiesDisplay;
+}
+
 /**
  * \return True to show slow properties available on request.
  */
@@ -968,6 +1076,46 @@ bool RSettings::getPropertyEditorShowOnRequest() {
     return propertyEditorShowOnRequest;
 }
 
+/**
+ * \return True to align left aligned simple text to the reference point exactly.
+ */
+bool RSettings::getSimpleTextAlignLeft() {
+    if (simpleTextAlignLeft==-1) {
+        simpleTextAlignLeft = getBoolValue("TextRendering/SimpleTextAlignLeft", false);
+    }
+    return simpleTextAlignLeft;
+}
+
+/**
+ * \return True to render polylines with a very thin global width as 1 px.
+ */
+bool RSettings::getRenderThinPolylines1px() {
+    if (renderThinPolylines1px==-1) {
+        renderThinPolylines1px = getBoolValue("GraphicsView/RenderThinPolylines1px", true);
+    }
+    return renderThinPolylines1px;
+}
+
+/**
+ * \return Maximum render time for a single hatch in ms.
+ */
+int RSettings::getMaxHatchTime() {
+    if (maxHatchTime==-1) {
+        maxHatchTime = getIntValue("GraphicsView/MaxHatchTime", 2000);
+    }
+    return maxHatchTime;
+}
+
+/**
+ * \return Maximum complexity for a hatch to render at recommended arc resolution.
+ */
+int RSettings::getMaxHatchComplexity() {
+    if (maxHatchComplexity==-1) {
+        maxHatchComplexity = getIntValue("GraphicsView/MaxHatchComplexity", 2000);
+    }
+    return maxHatchComplexity;
+}
+
 /**
  * \return Polar coordinate separator (<).
  */
@@ -999,14 +1147,20 @@ QString RSettings::getRelativeCoordinatePrefix() {
 }
 
 /**
- * \return True for macOS dark mode only.
+ * \return True for macOS or Windows dark mode.
  */
 bool RSettings::isDarkMode() {
     if (darkMode==-1) {
-#ifdef Q_OS_MAC
+#if defined(Q_OS_MAC)
         darkMode = (isMacDarkMode() ? 1 : 0);
-#else
-        darkMode = 0;
+#elif defined(Q_OS_WIN32)
+        const QPalette defaultPalette;
+        if (defaultPalette.color(QPalette::WindowText).lightness() > defaultPalette.color(QPalette::Window).lightness()) {
+            darkMode = 1;
+        }
+        else {
+            darkMode = 0;
+        }
 #endif
     }
     return darkMode==1;
@@ -1019,7 +1173,7 @@ bool RSettings::hasDarkGuiBackground() {
             darkGuiBackground = 1;
         }
         else {
-#ifdef Q_OS_MAC
+#if defined(Q_OS_MAC)
             // detect macOS dark mode:
             if (isMacDarkMode()) {
                 darkGuiBackground = 1;
@@ -1036,6 +1190,14 @@ bool RSettings::hasDarkGuiBackground() {
 //            else {
 //                darkGuiBackground = 0;
 //            }
+#elif defined(Q_OS_WIN32)
+            // detect Windows dark mode:
+            if (isDarkMode()) {
+                darkGuiBackground = 1;
+            }
+            else {
+                darkGuiBackground = 0;
+            }
 #else
             darkGuiBackground = 0;
 #endif
@@ -1103,7 +1265,7 @@ QString RSettings::getQtVersionString() {
 }
 
 /**
- * \return True if application was compiled against the given major Qt version.
+ * \return True if application was compiled against at least the given major Qt version.
  */
 bool RSettings::isQt(int majorVersion) {
     return QT_VERSION >= majorVersion<<16;
@@ -1132,6 +1294,22 @@ QString RSettings::getCompilerVersion() {
         return "MSVC++ 12.0 (2013)";
 #   elif _MSC_VER==1900
         return "MSVC++ 14.0 (2015)";
+#   elif _MSC_VER==1910
+        return "MSVC++ 14.10 (2017)";
+#   elif _MSC_VER==1911
+        return "MSVC++ 14.11 (2017)";
+#   elif _MSC_VER==1912
+        return "MSVC++ 14.12 (2017)";
+#   elif _MSC_VER==1913
+        return "MSVC++ 14.13 (2017)";
+#   elif _MSC_VER==1914
+        return "MSVC++ 14.14 (2017)";
+#   elif _MSC_VER==1915
+        return "MSVC++ 14.15 (2017)";
+#   elif _MSC_VER==1916
+        return "MSVC++ 14.16 (2017)";
+#   elif _MSC_VER==1929
+        return "MSVC++ 16.11 (2019)";
 #   endif
 #endif
     return "Unknown";
@@ -1166,7 +1344,7 @@ QString RSettings::getOSVersion() {
         return "Windows 8.1";
     // QSysInfo::WV_WINDOWS10:
     case 0x00c0:
-        return "Windows 10";
+        return "Windows 10 or 11";
     default:
         return "Windows >= 10";
     }
@@ -1191,16 +1369,16 @@ QString RSettings::getOSVersion() {
     case QSysInfo::MV_10_7:
         return "Mac OS X 10.7 (Lion)";
     case QSysInfo::MV_10_8:
-        return "Mac OS X 10.8 (Mountain Lion)";
+        return "OS X 10.8 (Mountain Lion)";
     // QSysInfo::MV_10_9:
     case 0x000B:
-        return "Mac OS X 10.9 (Mavericks)";
+        return "OS X 10.9 (Mavericks)";
     // QSysInfo::MV_10_10:
     case 0x000C:
-        return "Mac OS X 10.10 (Yosemite)";
+        return "OS X 10.10 (Yosemite)";
     // QSysInfo::MV_10_11:
     case 0x000D:
-        return "Mac OS X 10.11 (El Capitan)";
+        return "OS X 10.11 (El Capitan)";
     // QSysInfo::MV_10_12:
     case 0x000E:
         return "macOS 10.12 (Sierra)";
@@ -1503,19 +1681,26 @@ double RSettings::getDoubleValue(const QString& key, double defaultValue) {
 
     // if the variant is a list or string list, return the first entry
     // used for example for stored RMathLineEdit values
-    if (ret.type()==QVariant::List || ret.canConvert<QStringList>()) {
+    if (ret.type()==QVariant::List
+#if QT_VERSION < 0x060000
+        // Qt 6: strings can always be converted to string lists.
+        // "1.02" is converted to a list of "1", ".", "0", "2":
+        || ret.canConvert<QStringList>()
+#endif
+        ) {
         if (ret.toList().count()>0) {
             ret = ret.toList().at(0);
         }
     }
 
     QString str = ret.toString();
+
     double d;
     if (str.isEmpty()) {
         return defaultValue;
     }
-    else if (QRegExp("^[-+]?[0-9]*\\.?[0-9]+([eE][-+]?[0-9]+)?$").exactMatch(str)) {
-        d = ret.toDouble();
+    else if (RS::exactMatch(QRegularExpression("^[-+]?[0-9]*\\.?[0-9]+([eE][-+]?[0-9]+)?$"), str)) {
+        d = str.toDouble();
     }
     else {
         d = RMath::eval(str);
@@ -1567,6 +1752,105 @@ QChar RSettings::getCharValue(const QString& key, const QChar& defaultValue) {
     return ret[0];
 }
 
+QStringList RSettings::getScaleList(const RS::Unit unit) {
+    QString key;
+    QStringList defaults;
+
+    // add appropriate scale items:
+    if (RUnit::isMetric(unit)) {
+        key = "Print/ScaleListMetric";
+        defaults << "1:1" << "1:2" << "1:5" << "1:10" << "1:20" << "1:25" << "1:50" << "1:75" <<
+                    "1:100" << "1:125" << "1:150" << "1:175" <<
+                    "1:200" << "1:250" << "1:500" << "1:750" <<
+                    "1:1000" << "1:2500" << "1:5000" << "1:7500" <<
+                    "1:10000" << "1:25000" << "1:50000" << "1:75000" <<
+                    "1:100000" << "1:250000" << "1:500000" << "1:750000" <<
+                    "1:1000000" <<
+                    "2:1" << "5:1" << "10:1" << "20:1" << "25:1" << "50:1" << "75:1" <<
+                    "100:1" << "125:1" << "150:1" << "175:1" <<
+                    "200:1" << "250:1" << "500:1" << "750:1" <<
+                    "1000:1" << "2500:1" << "5000:1" << "7500:1" <<
+                    "10000:1" << "25000:1" << "50000:1" << "75000:1" <<
+                    "100000:1" << "250000:1" << "500000:1" << "750000:1" <<
+                    "1000000:1";
+    }
+    else {
+        key = "Print/ScaleListImperial";
+
+
+//        defaults << "1\" = 1\"" << "1\" = 2\"" << "1\" = 4\"" << "1\" = 8\"" << "1\" = 16\"" <<
+//                "1\" = 32\"" << "1\" = 64\"" << "1\" = 128\"" << "1\" = 256\"" <<
+//                "1\" = 512\"" << "1\" = 1024\"" << "1\" = 2048\"" << "1\" = 4096\"" <<
+
+//                "1/4096\" = 1'-0\"" << "1/2048\" = 1'-0\"" << "1/1024\" = 1'-0\"" <<
+//                "1/512\" = 1'-0\"" << "1/256\" = 1'-0\"" << "1/128\" = 1'-0\"" <<
+//                "1/64\" = 1'-0\"" <<
+//                "1/32\" = 1'-0\"" <<
+//                "1/16\" = 1'-0\"" <<
+//                "3/32\" = 1'-0\"" <<
+//                "1/8\" = 1'-0\"" <<
+//                "3/16\" = 1'-0\"" <<
+//                "1/4\" = 1'-0\"" <<
+//                "3/8\" = 1'-0\"" <<
+//                "1/2\" = 1'-0\"" <<
+//                "3/4\" = 1'-0\"" <<
+//                "1\" = 1'-0\"" << "2\" = 1'-0\"" << "3\" = 1'-0\"" << "4\" = 1'-0\"" <<
+//                "5\" = 1'-0\"" << "6\" = 1'-0\"" << "7\" = 1'-0\"" << "8\" = 1'-0\"" <<
+//                "9\" = 1'-0\"" << "10\" = 1'-0\"" << "11\" = 1'-0\"";
+
+        defaults << "1\" = 1\""
+                 << "1\" = 2\""
+                 << "1\" = 4\""
+                 << "1\" = 8\""
+                 << "1\" = 16\""
+                 << "1\" = 32\""
+                 << "1\" = 64\""
+                 << "1\" = 128\""
+                 << "1\" = 256\""
+                 << "1\" = 512\""
+                 << "1\" = 1024\""
+                 << "1\" = 2048\""
+                 << "1\" = 4096\"";
+
+        // Standard Imperial Engineering Scale
+        defaults << "1\"= 10'"
+                 << "1\" = 20'"
+                 << "1\" = 30'"
+                 << "1\" = 40'"
+                 << "1\" = 50'"
+                 << "1\" = 60'"
+                 << "1\" = 70'"
+                 << "1\" = 80'"
+                 << "1\" = 90'"
+                 << "1\" = 100'"
+                 << "1\" = 150'"
+                 << "1\" = 200'"
+                 << "1\" = 300'"
+                 << "1\" = 400'"
+                 << "1\" = 500'";
+
+        // Standard Imperial Architectural Scale
+        defaults << "1' = 1'-0\""
+                 << "6\" = 1'-0\""
+                 << "3\" = 1'-0\""
+                 << "1 1/2\" = 1'-0\""
+                 << "1\" = 1'-0\""
+                 << "3/4\" = 1'-0\""
+                 << "1/2\" = 1'-0\""
+                 << "3/8\" = 1'-0\""
+                 << "1/4\" = 1'-0\""
+                 << "3/16\" = 1'-0\""
+                 << "1/8\" = 1'-0\""
+                 << "3/32\" = 1'-0\""
+                 << "1/16\" = 1'-0\""
+                 << "1/32\" = 1'-0\""
+                 << "1/64\" = 1'-0\""
+                 << "1/128\" = 1'-0\"";
+    }
+
+    return getStringListValue(key, defaults);
+}
+
 /**
  * Sets the variable with the given key and value, overwriting an existing value if overwrite is true (default).
  */
@@ -1650,6 +1934,13 @@ bool RSettings::getAutoScaleLinetypePatterns() {
     return (bool)autoScaleLinetypePattern;
 }
 
+bool RSettings::getApplyLineweightToPoints() {
+    if (applyLineweightToPoints==-1) {
+        applyLineweightToPoints = getValue("GraphicsView/ApplyLineweightToPoints", QVariant(false)).toBool();
+    }
+    return (bool)applyLineweightToPoints;
+}
+
 bool RSettings::getUseSecondarySelectionColor() {
     if (useSecondarySelectionColor==-1) {
         useSecondarySelectionColor = getValue("GraphicsViewColors/UseSecondarySelectionColor", QVariant(false)).toBool();
@@ -1678,6 +1969,10 @@ bool RSettings::getPositionByMousePress() {
     return (bool)positionByMousePress;
 }
 
+void RSettings::setAllowMouseMoveInterruptionsOverride(bool on) {
+    allowMouseMoveInterruptions = (int)on;
+}
+
 bool RSettings::getAllowMouseMoveInterruptions() {
     if (allowMouseMoveInterruptions==-1) {
         allowMouseMoveInterruptions = getValue("GraphicsView/AllowMouseMoveInterruptions", QVariant(true)).toBool();
@@ -1728,10 +2023,18 @@ void RSettings::resetCache() {
     previewEntities = -1;
     limitZoomAndScroll = -1;
     autoScaleLinetypePattern = -1;
+    applyLineweightToPoints = -1;
     useSecondarySelectionColor = -1;
     useSolidLineSelection = -1;
     arcAngleLengthThreshold = -1;
     positionByMousePress = -1;
+    maxReferencePointEntities = -1;
+    maxReferencePointEntitiesDisplay = -1;
+    propertyEditorShowOnRequest = -1;
+    simpleTextAlignLeft = -1;
+    renderThinPolylines1px = -1;
+    maxHatchTime = -1;
+    maxHatchComplexity = -1;
     minArcAngleStep = -1;
     dashThreshold = -1;
     textRenderedAsText = -1;
@@ -1743,9 +2046,9 @@ void RSettings::resetCache() {
     ignoreAllReferencePoints = -1;
     referencePointSize = -1;
     referencePointShape = -1;
-    cartesianCoordinateSeparator = QString::null;
-    polarCoordinateSeparator = QString::null;
-    relativeCoordinatePrefix = QString::null;
+    cartesianCoordinateSeparator = QString();
+    polarCoordinateSeparator = QString();
+    relativeCoordinatePrefix = QString();
     mouseThreshold = -1;
     themePath = QString();
     cache.clear();
