@@ -22,12 +22,12 @@
 
 #include "core_global.h"
 
-#include <QDir>
-#include <QSettings>
-#include <QFont>
+#include <QStringList>
+#include <QVariant>
 
 #include "RColor.h"
 #include "RBox.h"
+#include "RMath.h"
 
 // workaround for src2srcml bug:
 #ifndef RDEFAULT_RCOLOR
@@ -54,6 +54,9 @@
 #define RDEFAULT_QLISTINT QList<int>()
 #endif
 
+class QFont;
+class QSettings;
+
 /**
  * \ingroup core
  * \scriptable
@@ -97,6 +100,7 @@ public:
     static QString getDesktopLocation();
     static QString getDocumentsLocation();
     static QString getHomeLocation();
+    static QString getPluginsLocation();
 
     //static void setEventBlocking(bool on);
     //static bool isEventBlockingEnabled();
@@ -126,6 +130,11 @@ public:
     static RColor getEndReferencePointColor();
     static RColor getSecondaryReferencePointColor();
     static RColor getTertiaryReferencePointColor();
+    static RColor getCrossHairColor();
+    static RColor getCrossHairColorInactive();
+    static RColor getGridColor();
+    static RColor getMetaGridColor();
+    static RColor getOriginColor();
 
     static bool getHighResolutionGraphicsView();
     static bool getAutoScaleGrid();
@@ -255,6 +264,9 @@ public:
     static QSettings* getQSettings();
 
     static void resetCache();
+    static void resetDarkModeCache() {
+        darkMode = -1;
+    }
 
     static void setXDataEnabled(bool on);
     static bool isXDataEnabled();
@@ -269,6 +281,7 @@ public:
 
     static int getMouseThreshold();
     static bool getPositionByMousePress();
+    static void setAllowMouseMoveInterruptionsOverride(bool on);
     static bool getAllowMouseMoveInterruptions();
 
     static bool isTextRenderedAsText();
@@ -284,6 +297,9 @@ public:
     static int getMaxReferencePointEntitiesDisplay();
     static bool getPropertyEditorShowOnRequest();
     static bool getSimpleTextAlignLeft();
+    static bool getRenderThinPolylines1px();
+    static int getMaxHatchTime();
+    static int getMaxHatchComplexity();
     static QString getPolarCoordinateSeparator();
     static QString getCartesianCoordinateSeparator();
     static QString getRelativeCoordinatePrefix();
@@ -318,6 +334,11 @@ private:
     static RColor* endReferencePointColor;
     static RColor* secondaryReferencePointColor;
     static RColor* tertiaryReferencePointColor;
+    static RColor* crossHairColor;
+    static RColor* crossHairColorInactive;
+    static RColor* gridColor;
+    static RColor* metaGridColor;
+    static RColor* originColor;
     static int darkMode;
     static int darkGuiBackground;
     static int snapRange;
@@ -354,6 +375,10 @@ private:
     static int maxReferencePointEntitiesDisplay;
     static int propertyEditorShowOnRequest;
     static int simpleTextAlignLeft;
+    static int renderThinPolylines1px;
+    static int maxHatchTime;
+    static int maxHatchComplexity;
+    static double devicePixelRatio;
     static QString polarCoordinateSeparator;
     static QString cartesianCoordinateSeparator;
     static QString relativeCoordinatePrefix;
