@@ -17,7 +17,10 @@
  * along with QCAD.
  */
 #include "RViewportData.h"
+#include "RDocument.h"
+#include "REntity.h"
 #include "RMouseEvent.h"
+#include "RRefPoint.h"
 
 RViewportData::RViewportData()
     : viewportId(RObject::INVALID_ID),
@@ -155,6 +158,7 @@ double RViewportData::getDistanceTo(const RVector& point, bool limited, double r
     double ret = RMAXDOUBLE;
 
     RBox viewportBox(position, width, height);
+    viewportBox.growXY(range);
     if (viewportBox.contains(point)) {
         ret = strictRange;
     }
@@ -172,7 +176,7 @@ QList<QSharedPointer<RShape> > RViewportData::getShapes(const RBox& queryBox, bo
     // border:
     QList<RLine> lines = RBox(position, width, height).getLines2d();
     for (int i=0; i<lines.length(); i++) {
-        ret.append(QSharedPointer<RShape>(lines[i].clone()));
+        ret.append(lines[i].clone());
     }
 
     // shapes inside viewport:
