@@ -17,11 +17,10 @@
  * along with QCAD.
  */
 #include <cmath>
-#include <typeinfo>
+#include <QDebug>
 
 #include "RArc.h"
 #include "RCircle.h"
-#include "RDebug.h"
 #include "REllipse.h"
 #include "RLine.h"
 #include "RMath.h"
@@ -38,6 +37,15 @@ double RShape::epsTolerance = 1.0e-02;
 int RShape::errorCode = 0;
 RShapeProxy* RShape::shapeProxy = NULL;
 
+
+RShape::RShape() {
+    //RDebug::incCounter("RShape");
+}
+
+RShape::~RShape() {
+    //RDebug::decCounter("RShape");
+}
+
 bool RShape::isFullEllipseShape(const RShape& s) {
     return s.getShapeType()==RShape::Ellipse && dynamic_cast<const REllipse&>(s).isFullEllipse();
 }
@@ -108,7 +116,7 @@ QList<RVector> RShape::filterOnShape(const QList<RVector>& pointList, bool limit
 RVector RShape::getVectorFromEndpointTo(const RVector& point) const {
     QList<RVector> endPoints = getEndPoints();
     RVector closest = point.getClosest(endPoints);
-    return point - closest;
+    return point.get2D() - closest;
 }
 
 /**
@@ -761,21 +769,10 @@ QList<RVector> RShape::getIntersectionPointsLE(const RLine& line1,
     QList<RVector> res;
 
     // find out if line1 is (almost) a tangent:
-    QList<RLine> tangents = ellipse2.getTangents(line1.getMiddlePoint());
-    for (int i=0; i<tangents.length(); i++) {
-        double a = tangents[i].getAngle();
-        double ad1 = fabs(RMath::getAngleDifference180(a, line1.getDirection1()));
-        double ad2 = fabs(RMath::getAngleDifference180(a, line1.getDirection2()));
-
-        if (ad1 < 1.0e-2 || ad2 < 1.0e-2) {
-            RVector candidate = tangents[i].getEndPoint();
-            if (!limited1 || line1.isOnShape(candidate)) {
-                res.append(candidate);
-            }
-
-            // no need to continue: max. one tangent possible:
-            return res;
-        }
+    RVector tangentPoint = ellipse2.getTangentPoint(line1);
+    if (tangentPoint.isValid()) {
+        res.append(tangentPoint);
+        return res;
     }
 
     // rotate into normal position:
@@ -1766,6 +1763,31 @@ void RShape::print(QDebug dbg) const {
             << ")";
 }
 
+QList<RPolyline> RShape::getPolylines(const QList<QSharedPointer<RShape> >& shapes) {
+    QList<QSharedPointer<RShape> > orderedShapes = getOrderedShapes(shapes);
+    QList<RPolyline> ret;
+
+    RPolyline pl;
+
+    for (int i=0; i<shapes.length(); i++) {
+        QSharedPointer<RShape> shape = shapes.at(i);
+
+        if (!pl.isEmpty() && !pl.getEndPoint().equalsFuzzy(shape->getStartPoint())) {
+            // new polyline:
+            ret.append(pl);
+            pl = RPolyline();
+        }
+
+        pl.appendShape(*shape);
+
+        if (i==shapes.length()-1) {
+            ret.append(pl);
+        }
+    }
+
+    return ret;
+}
+
 QList<QSharedPointer<RShape> > RShape::getOrderedShapes(const QList<QSharedPointer<RShape> >& shapes) {
     QList<QSharedPointer<RShape> > ret;
     //RVector cursor = RVector::invalid;
@@ -1832,9 +1854,9 @@ QList<QSharedPointer<RShape> > RShape::getOrderedShapes(const QList<QSharedPoint
                         found = true;
                     }
                     if (ep.equalsFuzzy(shape2->getEndPoint())) {
-                        RShape* s = shape2->clone();
+                        QSharedPointer<RShape> s = shape2->clone();
                         s->reverse();
-                        contour.append(QSharedPointer<RShape>(s));
+                        contour.append(s);
                         traversed.insert(k);
                         found = true;
                     }
@@ -1844,9 +1866,9 @@ QList<QSharedPointer<RShape> > RShape::getOrderedShapes(const QList<QSharedPoint
                         found = true;
                     }
                     if (sp.equalsFuzzy(shape2->getStartPoint())) {
-                        RShape* s = shape2->clone();
+                        QSharedPointer<RShape> s = shape2->clone();
                         s->reverse();
-                        contour.append(QSharedPointer<RShape>(s));
+                        contour.append(s);
                         traversed.insert(k);
                         found = true;
                     }
@@ -2081,9 +2103,9 @@ QList<QSharedPointer<RShape> > RShape::getOffsetLines(const RShape& shape, doubl
         RVector distanceV;
         for (int n=1; n<=number; ++n) {
             distanceV.setPolar(distance * n, a);
-            RShape* parallel = shape.clone();
+            QSharedPointer<RShape> parallel = shape.clone();
             parallel->move(distanceV);
-            ret.append(QSharedPointer<RShape>(parallel));
+            ret.append(parallel);
         }
     }
     return ret;
@@ -2152,7 +2174,7 @@ QList<QSharedPointer<RShape> > RShape::getOffsetArcs(const RShape& shape, double
         }
 
         for (int n=1; n<=number; ++n) {
-            QSharedPointer<RShape> s = QSharedPointer<RShape>(shape.clone());
+            QSharedPointer<RShape> s = shape.clone();
 
             if (arc!=NULL) {
                 QSharedPointer<RArc> concentric = s.dynamicCast<RArc>();
@@ -2195,7 +2217,7 @@ QList<QSharedPointer<RShape> > RShape::getReversedShapeList(const QList<QSharedP
     QList<QSharedPointer<RShape> > ret;
 
     for (int i=shapes.length()-1; i>=0; i--) {
-        QSharedPointer<RShape> shape = QSharedPointer<RShape>(shapes[i]->clone());
+        QSharedPointer<RShape> shape = shapes[i]->clone();
         shape->reverse();
         ret.append(shape);
     }
@@ -2213,7 +2235,7 @@ QList<QSharedPointer<RShape> > RShape::splitAt(const QList<RVector>& points) con
     Q_UNUSED(points)
 
     QList<QSharedPointer<RShape> > ret;
-    ret.append(QSharedPointer<RShape>(clone()));
+    ret.append(clone());
     return ret;
 }
 
@@ -2235,7 +2257,7 @@ QList<QSharedPointer<RShape> > RShape::trim(
 
     int i1=0;
     QSharedPointer<RShape> segment;
-    QSharedPointer<RShape> trimShapeSimple = QSharedPointer<RShape>(trimShape.clone());
+    QSharedPointer<RShape> trimShapeSimple = trimShape.clone();
     if (isPolylineShape(trimShape)) {
         const RPolyline& polyline = dynamic_cast<const RPolyline&>(trimShape);
         i1 = polyline.getClosestSegment(trimClickPos);
@@ -2250,7 +2272,7 @@ QList<QSharedPointer<RShape> > RShape::trim(
     }
 
     int i2=0;
-    QSharedPointer<RShape> limitingShapeSimple = QSharedPointer<RShape>(limitingShape.clone());
+    QSharedPointer<RShape> limitingShapeSimple = limitingShape.clone();
     if (isPolylineShape(limitingShape)) {
         const RPolyline& polyline = dynamic_cast<const RPolyline&>(limitingShape);
         i2 = polyline.getClosestSegment(limitingClickPos);
@@ -2267,6 +2289,26 @@ QList<QSharedPointer<RShape> > RShape::trim(
     // possible trim points:
     QList<RVector> sol = trimShapeSimple->getIntersectionPoints(*limitingShapeSimple, false);
     if (sol.isEmpty()) {
+        // check if two lines are in line and replace with one line
+        if (RShape::isLineShape(trimShape) && RShape::isLineShape(limitingShape)) {
+            const RLine& trimLine = dynamic_cast<const RLine&>(trimShape);
+            const RLine& limitingLine = dynamic_cast<const RLine&>(limitingShape);
+
+            if (trimLine.isCollinear(limitingLine)) {
+                QList<RVector> pts;
+                pts.append(trimLine.getStartPoint());
+                pts.append(trimLine.getEndPoint());
+                pts.append(limitingLine.getStartPoint());
+                pts.append(limitingLine.getEndPoint());
+                RVector minP = RVector::getMinimum(pts);
+                pts = RVector::getSortedByDistance(pts, minP);
+                RLine newTrimmedLine(pts[1], pts[3]);
+
+                return QList<QSharedPointer<RShape> >() << QSharedPointer<RShape>(newTrimmedLine.clone());
+            }
+        }
+
+
         return QList<QSharedPointer<RShape> >();
     }
 
@@ -2298,10 +2340,10 @@ QList<QSharedPointer<RShape> > RShape::trim(
     }
     else {
         if (samePolyline) {
-            trimmedTrimShape = QSharedPointer<RShape>(trimShapeSimple->clone());
+            trimmedTrimShape = trimShapeSimple->clone();
         }
         else {
-            trimmedTrimShape = QSharedPointer<RShape>(trimShape.clone());
+            trimmedTrimShape = trimShape.clone();
         }
     }
 
@@ -2318,10 +2360,10 @@ QList<QSharedPointer<RShape> > RShape::trim(
         }
         else {
             if (samePolyline) {
-                trimmedLimitingShape = QSharedPointer<RShape>(limitingShapeSimple->clone());
+                trimmedLimitingShape = limitingShapeSimple->clone();
             }
             else {
-                trimmedLimitingShape = QSharedPointer<RShape>(limitingShape.clone());
+                trimmedLimitingShape = limitingShape.clone();
             }
         }
     }
@@ -2410,7 +2452,7 @@ QList<QSharedPointer<RShape> > RShape::trim(
     if (samePolyline && isPolylineShape(trimShape)) {
         const RPolyline& polyline = dynamic_cast<const RPolyline&>(trimShape);
         RPolyline pl = polyline.modifyPolylineCorner(*trimmedTrimShape, ending1, i1, *trimmedLimitingShape, ending2, i2);
-        ret.append(QSharedPointer<RShape>(pl.clone()));
+        ret.append(pl.clone());
     }
     else {
         ret.append(trimmedTrimShape);
@@ -2530,12 +2572,12 @@ QList<QSharedPointer<RShape> > RShape::roundShapes(
 
     QSharedPointer<RShape> trimmed1, trimmed2;
     if (samePolyline) {
-        trimmed1 = QSharedPointer<RShape>(simpleShape1->clone());
-        trimmed2 = QSharedPointer<RShape>(simpleShape2->clone());
+        trimmed1 = simpleShape1->clone();
+        trimmed2 = simpleShape2->clone();
     }
     else {
-        trimmed1 = QSharedPointer<RShape>(shape1->clone());
-        trimmed2 = QSharedPointer<RShape>(shape2->clone());
+        trimmed1 = shape1->clone();
+        trimmed2 = shape2->clone();
     }
 
     RS::Ending ending1 = RS::EndingNone;
@@ -2665,20 +2707,19 @@ QSharedPointer<RShape> RShape::transformArc(const RShape& shape, RShapeTransform
         c = circle.getCenter();
     }
 
+    // corners of bounding box of untransformed arc:
     RVector v1 = c + r1 + r2;
     RVector v2 = c + r1 - r2;
     RVector v3 = c - r1 - r2;
     RVector v4 = c - r1 + r2;
 
+    // transform conrners:
     v1 = transformation.transform(v1);
     v2 = transformation.transform(v2);
     v3 = transformation.transform(v3);
     v4 = transformation.transform(v4);
 
-    //var ret = [];
     REllipse ellipse = REllipse::createInscribed(v1, v2, v3, v4);
-    //var ellipse = ShapeAlgorithms.createEllipseInscribedFromVertices(v1, v2, v3, v4);
-    //ret.push(ellipse.copy());
 
     if (isArcShape(shape) || isEllipseShape(shape)) {
         RVector sp = shape.getStartPoint();
@@ -2701,9 +2742,6 @@ QSharedPointer<RShape> RShape::transformArc(const RShape& shape, RShapeTransform
         }
     }
 
-    //ret.push(ShapeAlgorithms.ellipseToArcCircleEllipse(ellipse));
-    //ret = ret.concat([new RLine(v1, v2), new RLine(v2, v3), new RLine(v3, v4), new RLine(v4, v1)]);
-
     return RShape::ellipseToArcCircleEllipse(ellipse);
 }
 
@@ -2724,7 +2762,7 @@ QSharedPointer<RShape> RShape::ellipseToArcCircleEllipse(const REllipse& ellipse
         }
     }
     else {
-        return QSharedPointer<RShape>(ellipse.clone());
+        return ellipse.clone();
     }
 }
 
@@ -2732,3 +2770,7 @@ void RShape::dump() const{
     qDebug() << *this;
 }
 
+QCADCORE_EXPORT QDebug operator<<(QDebug dbg, const RShape& s) {
+    s.print(dbg);
+    return dbg;
+}
