@@ -22,25 +22,14 @@
 
 #include "gui_global.h"
 
-#include <QtCore>
-#include <QFrame>
-#include <QFocusFrame>
+#include <QElapsedTimer>
 #include <QWidget>
-#include <QPinchGesture>
-
-#include "RGraphicsViewImage.h"
-#include "RPainterPath.h"
-
-class RAction;
-class RDocument;
-class RDocumentInterface;
-class RFocusFrame;
-class RGraphicsSceneQt;
-class RLine;
-class RSnap;
-class RSnapRestriction;
 
+#include "RVector.h"
 
+class QFrame;
+class QGestureEvent;
+class RGraphicsViewImage;
 
 /**
  * \brief QWidget based 2d graphics view.
@@ -52,12 +41,18 @@ class RSnapRestriction;
  * \scriptable
  * \generateScriptShell
  */
-class QCADGUI_EXPORT RGraphicsViewQt : public QWidget, public RGraphicsViewImage {
+class QCADGUI_EXPORT RGraphicsViewQt : public QWidget {
     Q_OBJECT
 
 public:
     RGraphicsViewQt(QWidget* parent=NULL, bool showFocus=true);
     virtual ~RGraphicsViewQt();
+
+    void setImageView(RGraphicsViewImage* v);
+
+    RGraphicsViewImage* getImageView() const {
+        return imageView;
+    }
     
     void disableGestures() {
         gesturesEnabled = false;
@@ -65,11 +60,6 @@ public:
         ungrabGesture(Qt::PinchGesture);
     }
 
-    virtual void repaintView();
-    virtual void repaintNow();
-
-    virtual void giveFocus();
-    virtual bool hasFocus();
     virtual void removeFocus();
 
     virtual int getWidth() const;
@@ -79,36 +69,16 @@ public:
     virtual bool getSignalsBlocked() const;
     virtual void setSignalsBlocked(bool on);
     
-    virtual QCursor getCursor();
-    virtual void setCursor(Qt::CursorShape cursorShape);
-    virtual void setCursor(const QCursor& cursor);
-
     void setFocusFrameWidget(QFrame* w);
 
-    virtual void viewportChangeEvent();
-
-    virtual void emitUpdateSnapInfo(RSnap* snap, RSnapRestriction* restriction);
-    virtual void emitUpdateTextLabel(const RTextLabel& textLabel);
-
     virtual void simulateMouseMoveEvent();
 
-    virtual double getDevicePixelRatio() const;
-
-    virtual bool registerForFocus() const {
-        return true;
-    }
-
     virtual QSize sizeHint() const;
 
 signals:
     void drop(QDropEvent* event);
     void dragEnter(QDragEnterEvent* event);
 
-    void viewportChanged();
-
-    void updateSnapInfo(QPainter* painter, RSnap* snap, RSnapRestriction* restriction);
-    void updateTextLabel(QPainter* painter, const RTextLabel& textLabel);
-
 protected:
 
     bool event(QEvent* e);
@@ -130,22 +100,30 @@ protected:
     virtual void keyReleaseEvent(QKeyEvent* event);
     virtual void dragEnterEvent(QDragEnterEvent* event);
     virtual void dropEvent(QDropEvent* event);
+    virtual bool focusNextPrevChild(bool next) {
+        // ignore tab key:
+        return false;
+    }
+
+private slots:
+    void imageViewDeleted();
 
 private:
-    QTransform previousView;
     //! remember last mouse button state for wacom bug workaround
     Qt::MouseButtons lastButtonState;
 
     bool showFocus;
 
     QFrame* focusFrameWidget;
-    QCursor lastCursor;
 
     bool gesturesEnabled;
     QElapsedTimer mouseClickTimer;
     RVector mousePressScreenPosition;
     RVector mousePressModelPosition;
     bool gotMouseButtonPress;
+
+    // backend to render to bitmap (can be QPainter or Skia):
+    RGraphicsViewImage* imageView;
 };
 
 Q_DECLARE_METATYPE(RGraphicsViewQt*)
