@@ -1,5 +1,3 @@
-#include <QtPlugin>
-
 #include "RDxfExporterFactory.h"
 #include "RDxfImporterFactory.h"
 #include "RDxfPlugin.h"
@@ -19,7 +17,7 @@ RPluginInfo RDxfPlugin::getPluginInfo() {
     RPluginInfo ret;
     ret.set("Version", QString("%1 (dxflib %2)").arg(RSettings::getVersionString()).arg(DL_VERSION));
     ret.set("ID", "DXF");
-    ret.set("Name", "DXF");
+    ret.set("Name", "QCAD");
     ret.set("Description",
         QString(
             "Import/export support for the DXF format. "
